class PaperlessApiTransactionsController < ApplicationController
  include PaperlessApiHelpers

  def self.set_target_before
    super + [:refresh_status, :cancel_transaction]
  end

  def apply_select
    PaperlessApiTransaction.cols_for_jbuilder
  end

  def before_filter(filter)
    return false if filter[:id] == 'transaction_type' && filter[:value] == 'null'
    return false if filter[:id] == 'state' && filter[:value] == 'null'

    if filter[:id] == "associated_order_number"
      filter[:id] = "paperless_tickets.order_records.number"
    elsif filter[:id] == "associated_ticket_barcode"
      filter[:id] = "paperless_tickets.ticket_barcode"
    end
    filter
  end

  def apply_filter(models, filter)
    return models unless filter # don't apply removed filter

    return super unless filter[:id] == 'order_find_query_id'

    models.joins(:order_find_queries).where(OrderFindQuery.arel_table[:id].eq(filter[:value]))
  end

  model_data_store(PaperlessApiTransaction)

  def before_set_target
    PaperlessApiTransaction.attached_to_ticket.join_for_jbuilder
  end

  def before_set_targets
    @models.attached_to_ticket.left_outer_joins(paperless_ticket: [:order_record])
  end

  def refresh_status
    resp = PaperlessApi::Synchronous::StatusEndpoint.call({}, @model.transaction_identifier)

    return render json: { error: resp[:error] }, status: :unprocessable_entity if resp[:error]

    PaperlessApi::Asynchronous::Responses::Response.process([{
                                                               transaction: @model.transaction_identifier,
                                                               results: resp[:response][:results],
                                                               message: resp[:response][:message]
                                                             }])

    render :show
  end

  def cancel_transaction
    if @model.cancel
      render :show, status: :ok
    else
      render json: @model.errors.full_messages, status: :unprocessable_entity
    end
  end

  def update_status
    params = transactions_params

    transactions = params[:transactions]

    PaperlessApi::Asynchronous::Responses::Response.process(transactions)

    send_api_response
  end

  private

  def transactions_params
    params.permit(transactions: [:transaction, :results, :message])
  end

  # Only allow a list of trusted parameters through.
  def model_params
    params.require(:paperless_api_transaction).permit(:state, :transaction_identifier, :request_endpoint, :request_body, :response_body, :created_at, :updated_at)
  end
end
