class TicketTemplatesController < ApplicationController
  model_data_store(TicketTemplate)

  def create
    @model = TicketTemplate.new(__mssql_model_params__.except(:id, :new_template_fields))

    handle_new_template_fields

    if @model.save
      render json: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def update
    @model.assign_attributes(__mssql_model_params__.except(:id, :new_template_fields))

    handle_new_template_fields

    if @model.save
      render json: @model, status: :ok, location: @model
    else
      render json: @model.errors.full_messages, status: :unprocessable_entity
    end
  end

  def available_ticket_templates_to_external_system
    render json: TicketTemplate.available_to_external, status: :ok
  end

  private

  def model_params
    params.require(:ticket_template).permit(:process_name, :template_name, :process_code, :workflow_id)
  end

  def new_template_field_params
    params.require(:ticket_template).permit(new_template_fields: [
                                                :ticket_template_id,
                                                :zone_identifier,
                                                :field_type,
                                                :side,
                                                :tag_id,
                                                :static_field,
                                                :static_default,
                                                :formatter_regex
    ])
  end

  def handle_new_template_fields
    new_template_fields_params = new_template_field_params[:new_template_fields]

    new_template_fields_params.each do |template_field|
      @model.ticket_template_fields.build(template_field)
    end
  end
end
