class TicketWorkstationsController < ApplicationController
  #include OrderDataCache

  def self.set_target_before
    super + [:call]
  end

  def before_filter(filter)
    if filter[:id] == 'action'
      filter[:value] = JSON.parse(filter[:value])
    end
    filter
  end

  model_data_store(TicketWorkstation)

  def create
    params = model_params

    return render json: {error: 'Missing Template'}, status: :unprocessable_entity if template_needed_and_missing?(params)

    @model = model_type.new(__mssql_model_params__.except(:id))
    if @model.save
      render json: @model, status: :created, location: @model
    else
      render json: @model.errors.full_messages, status: :unprocessable_entity
    end
  end

  def update
    params = model_params

    return render json: {error: 'Missing Template'}, status: :unprocessable_entity if template_needed_and_missing?(params)

    if @model.update(__mssql_model_params__.except(:id))
      render json: @model, status: :ok, location: @model
    else
      render json: @model.errors.full_messages, status: :unprocessable_entity
    end
  end

  def call
    resp = @model.call(params)

    render json: resp, status: :ok
  end

  private

  def model_params
    params.require(:ticket_workstation).permit(:name, :ticket_template_id, :display_order, :action)
  end

  def template_needed_and_missing?(params)
    return false unless params[:action] == 'write_template'
    return false unless params[:ticket_template_id].nil?
    true
  end
end
