import Box from "@material-ui/core/Box";
import * as React from "react";
import {makeStyles} from "@material-ui/core";
import {green, red} from "@material-ui/core/colors";
import Typography from "@material-ui/core/Typography";
import {observer} from "mobx-react-lite";
import {Close, Check} from "@material-ui/icons";
import {t} from "@lingui/macro";
import classNames from "classnames";

type AddStatusBadgeProps = {
    addStatus?: string | null;
    successfulText?: string;
}

const useStyles = makeStyles((theme) => ({
    success: {
        color: green[600]
    },
    failed: {
        color: red[600]
    },
    status: {
        fontWeight: 'bold',
    },
    hideOverflow: {
        overflow: "hidden",
        textOverflow: "ellipsis"
    }
}));

export const AddStatusBadge: React.FunctionComponent<AddStatusBadgeProps> = observer(({addStatus, successfulText}) => {
    const classes = useStyles();

    if (!addStatus) {
        return null
    }

    if (addStatus === 'success') {
        return (
            <Box display={'flex'} alignItems={'center'} className={classes.success}>
                <Check/>
                <Box ml={1} fontWeight={'bold'} className={classNames(classes.status, classes.hideOverflow)}>
                    {successfulText || t`Successful`}
                </Box>
            </Box>
        );
    }

    return (
        <Box display={'flex'} alignItems={'center'} className={classes.failed}>
            <Close/>
            <Box ml={1} >
                {t`failed`}
            </Box>
            <Box ml={0.5}>
                <Typography variant={"caption"} className={classes.hideOverflow}>{`(${addStatus})`}</Typography>
            </Box>
        </Box>
    );
});

