import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ButtonField, useFlag} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import Delete from "@material-ui/icons/Delete";
import {makeStyles} from "@material-ui/core";
import {useSnackbar} from "notistack";
import {WarningDialog} from "../generic/WarningDialog";
import {OrderRecordModel} from "../../stores/OrderRecordStore";

type DeleteOrderButtonProps = {
    model: OrderRecordModel;
}

const useStyles = makeStyles(theme => ({
    danger: {
        backgroundColor: theme.palette.error.main
    }
}));

export const DeleteOrderButton: React.FunctionComponent<DeleteOrderButtonProps> = observer(({model}) => {
    const classes = useStyles();
    const {enqueueSnackbar} = useSnackbar();

    const [isLoading, setIsLoading] = React.useState<boolean>(false);
    const [confirmOpen, handleOpenConfirm, handleCloseConfirm] = useFlag();

    const handleDelete = React.useCallback(async () => {
        handleCloseConfirm();
        setIsLoading(true);
        try {
            await model.delete()
        } catch (e) {
            console.error(e);
            enqueueSnackbar(t`An error occurred while deleting.`, {variant: 'error'});
        }
        setIsLoading(false);
    }, [enqueueSnackbar, model]);

    return (
        <React.Fragment>
            <ButtonField
                text={t`Delete`}
                onClick={handleOpenConfirm}
                loading={isLoading}
                variant={'contained'}
                disabled={!model.canDelete()}
                className={classes.danger}
                startIcon={<Delete/>}
            />
            <WarningDialog
                warningMessage={t`This action will also release any ticket associated to this order.`}
                open={confirmOpen}
                onConfirm={handleDelete}
                handleClose={handleCloseConfirm}
                critical
           />
        </React.Fragment>
    )
})