import * as React from "react";
import {observer} from "mobx-react-lite";
import {OperatorScannerField} from "../generic/OperatorScannerField";
import {t} from "@lingui/macro";
import {fetchByJobNumber, OrderRecordModel, OrderRecordStore} from "../../stores/OrderRecordStore";
import {useSnackbar} from "notistack";
import {useHistory} from "react-router-dom";

type JobScannerFieldProps = {
}

export const JobScannerField: React.FunctionComponent<JobScannerFieldProps> = observer(() => {

    const { enqueueSnackbar } = useSnackbar();
    const history = useHistory();

    const searchJobFunc = React.useCallback(async (jobNumber: string) => {

        const orderRecordModel = await fetchByJobNumber(jobNumber);
        if (orderRecordModel.fetchError) {
            enqueueSnackbar(t`Cannot find any match for Order Number or E-Ticket barcode: ${jobNumber}`, { variant: 'error' });
            return;
        }

        const model = (orderRecordModel as OrderRecordModel);
        const cachedModel = OrderRecordStore.createModel(model as OrderRecordModel);
        OrderRecordStore.setModel(cachedModel);
        history.push(`/orders/${model.id}/read`);

    }, []);

    return (
        <OperatorScannerField searchFunction={searchJobFunc} searchFieldPlaceHolderText={t`Order Number or E-Ticket Barcode`} />
    );
});