import * as React from "react";
import {observer} from "mobx-react-lite";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faReceipt} from "@rx-suite/pro-solid-svg-icons";
import {OrderRecordModel} from "../../stores/OrderRecordStore";
import {ButtonField, useFlag} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {LatestLaunchTransactionDialog} from "./LatestLaunchTransactionDialog";

type LatestLaunchTransactionButtonProps = {
    model: OrderRecordModel
}

export const LatestLaunchTransactionButton: React.FunctionComponent<LatestLaunchTransactionButtonProps> = observer(({model}) => {
    const [flag, setFlagTrue, setFlagFalse, toggleFlag] = useFlag();

    return <React.Fragment>
        <ButtonField
            text={t`View`}
            variant="contained"
            disabled={model.state === 'waiting_for_launch'}
            size={'medium'}
            onClick={() => setFlagTrue()}
            startIcon={<FontAwesomeIcon icon={faReceipt}/>}
        />
        <LatestLaunchTransactionDialog model={model} open={flag} handleClose={setFlagFalse}/>
    </React.Fragment>
})
