import * as React from "react";
import {observer} from "mobx-react-lite";
import {OrderRecordModel} from "../../stores/OrderRecordStore";
import {useSnackbar} from "notistack";
import {ButtonField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {DoubleArrow} from "@material-ui/icons";

type LaunchNowButtonProps = {
    model: OrderRecordModel;
    size?: 'small' | 'medium' | 'large';
}

export const LaunchNowButton: React.FunctionComponent<LaunchNowButtonProps> = observer(({model, size}) => {
    const {enqueueSnackbar} = useSnackbar();

    const [isLoading, setIsLoading] = React.useState<boolean>(false);

    const buttonText = () => {
        if(model.state === 'failed_launch') {
            return t`Relaunch`;
        }
        return t`Launch Now`;
    }

    const launchNow = React.useCallback(async () => {
        setIsLoading(true);

        try {
           await model.launchJob();
            enqueueSnackbar(`Job Launch requested`, { variant: 'success' });
        }catch (e) {
            if(e === 'NO_TICKET_AVAILABLE'){
                enqueueSnackbar(t`No e-ticket currently available`, { variant: 'error' });
            }else{
                console.error(e);
                enqueueSnackbar(`An issue occurred with 'Launch Now'`, { variant: 'error' });
            }
        }

        setIsLoading(false);
    }, [model]);

    return <ButtonField
        text={buttonText()}
        variant="contained"
        color="secondary"
        disabled={model.state === 'launched' || model.state === 'launching'}
        size={size || 'medium'}
        onClick={launchNow}
        loading={isLoading}
        startIcon={<DoubleArrow/>}
        style={{width: '140px'}}
   />
})
