import Box from "@material-ui/core/Box";
import * as React from "react";
import {makeStyles} from "@material-ui/core";
import {blue, green, grey, red} from "@material-ui/core/colors";
import classNames from "classnames";
import {observer} from "mobx-react-lite";
import {
    AddBoxOutlined,
    Check,
    Close,
    Publish
} from "@material-ui/icons";
import {OrderRecordModel, OrderRecordState} from "../../stores/OrderRecordStore";

type OrderStateBadgeProps = {
    model: OrderRecordModel;
}

const useStyles = makeStyles((theme) => ({
    waiting_for_launch: {
        color: grey[600]
    },
    launching: {
        color: blue[600]
    },
    launched: {
        color: green[600]
    },
    failed_launch : {
        color: red[600]
    }
}));


export const OrderStateBadge: React.FunctionComponent<OrderStateBadgeProps> = observer(({model}) => {
    const classes = useStyles();

    const stateClass = {
        launching: classes.launching,
        waiting_for_launch: classes.waiting_for_launch,
        failed_launch: classes.failed_launch,
        launched: classes.launched
    }[model.state as OrderRecordState];

    const stateIcon = {
        waiting_for_launch: <AddBoxOutlined/>,
        launching: <Publish/>,
        launched: <Check/>,
        failed_launch: <Close/>,
    }[model.state as OrderRecordState];

    const stateText = {
        launching: 'Launching',
        waiting_for_launch: 'Waiting For Launch',
        failed_launch: 'Failed To Launch',
        launched: 'Launched'
    }[model.state as OrderRecordState];

    return (
        <Box display={'flex'} alignItems={'center'} className={classNames(stateClass)}>
            {stateIcon}
            <Box ml={1} fontWeight={'bold'}>
                {stateText}
            </Box>
        </Box>
    );
});

