import * as React from "react";
import {observer} from "mobx-react-lite";
import {alpha, Box, makeStyles, Paper, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";
import {AttachFile, Edit} from "@material-ui/icons";
import {ButtonField, Conditional, useFlag, useModelContext, ModelActionButton} from "@rx-suite/ui";
import {OrderRecordModel} from "../../../stores/OrderRecordStore";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import {HotJobBadge} from "../HotJobBadge";
import {red} from "@material-ui/core/colors";
import {ToolbarTicketActions} from "./ToolbarTicketActions";
import {ChangeTicketTemplateDialog} from "./ChangeTicketTemplateDialog";
import {TicketCurrentDisplay} from "../../../pages/order_records/form/tabs/TicketCurrentDisplay";
import {PaperlessTicketModel, PaperlessTicketStore} from "../../../stores/PaperlessTicketStore";
import {SettingModel, SettingStore} from "../../../stores/SettingStore";

const useStyles = makeStyles((theme) => ({
    hotJob: {
        color: red[300],
        borderColor: red[300],
        backgroundColor: alpha(red[200], 0.1)
    }
}));

export const OrderRecordHeader: React.FunctionComponent = observer(() => {
    const classes = useStyles();

    const model = useModelContext() as OrderRecordModel;

    const [openChangeTemplate, handleOpenChangeTemplate, handleCloseChangeTemplate] = useFlag();

    const systemSettingModel = SystemSettingStore.selectedModel as SystemSettingModel;
    const settings = SettingStore.selectedModel as SettingModel;

    let ticket: undefined | PaperlessTicketModel = undefined;
    if(model.isAttachedToTicket){
        ticket = PaperlessTicketStore.get(model.paperless_ticket_id);
    }

    return (
        <Box display={'flex'} alignItems={'flex-start'} justifyContent={'space-between'}>
            <Box display={'flex'}>
                <Conditional condition={model.isAttachedToTicket}>
                    <Box mr={4}>
                        {ticket && <TicketCurrentDisplay ticket={ticket}/>}
                    </Box>
                </Conditional>
                <Box>
                    <Paper variant={'outlined'} className={model.is_hot_job ? classes.hotJob : undefined}>
                        <Box p={3}>
                            <Typography variant={'h5'}>{t`Order Number:` + ' ' + model.number}</Typography>
                            <Typography variant={'body1'}>{t`Entry Time:` + ' ' + systemSettingModel.printDateTime(model.entry_time)}</Typography>
                        </Box>
                        <Conditional condition={model.is_hot_job}>
                            <Box ml={4} mt={-3} mb={2}>
                                <HotJobBadge size={'md'}/>
                            </Box>
                        </Conditional>
                    </Paper>
                    {model.isAttachedToTicket &&
                        <Box>
                            <Box ml={-1}>
                                <ButtonField
                                    text={t`Change Template`}
                                    variant={'contained'}
                                    color={'secondary'}
                                    size={'large'}
                                    disabled={ticket?.releasing}
                                    onClick={handleOpenChangeTemplate}
                                    startIcon={<Edit/>}
                                />
                            </Box>
                            <ChangeTicketTemplateDialog open={openChangeTemplate} handleClose={handleCloseChangeTemplate}/>
                        </Box>
                    }
                </Box>
                <Conditional condition={!!model.paperless_ticket_barcode}>
                    <Box ml={3}>
                        <Paper variant={'outlined'}>
                            <Box p={3}>
                                <Typography variant={'h5'}>{t`Ticket Barcode:` + ' ' + model.paperless_ticket_barcode}</Typography>
                            </Box>
                        </Paper>
                    </Box>
                </Conditional>
            </Box>
            <Box display={'flex'}>
                <ToolbarTicketActions/>
                {!settings.isManualPairingMode &&
                    <Box ml={1}>
                        <ModelActionButton
                            name={'viewPdf'}
                            text={'View Ticket'}
                            variant={'contained'}
                            color={'primary'}
                            size={'large'}
                            startIcon={<AttachFile/>}
                            disabled={model.download_link === null}
                        />
                    </Box>
                }
            </Box>
        </Box>
    );
})
