import * as React from "react";
import {observer} from "mobx-react-lite";
import {Box} from "@material-ui/core";
import {Search} from "@material-ui/icons";
import {ModelActionButton, useModelContext} from "@rx-suite/ui";
import {faFire} from "@rx-suite/pro-solid-svg-icons/faFire";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {OrderRecordModel} from "../../../stores/OrderRecordStore";
import {LaunchNowButton} from "../LaunchNowButton";
import {PaperlessTicketModel, PaperlessTicketStore} from "../../../stores/PaperlessTicketStore";
import {useSnackbar} from "notistack";

export const ToolbarTicketActions: React.FunctionComponent = observer(() => {
    const {enqueueSnackbar} = useSnackbar();

    const model = useModelContext() as OrderRecordModel;

    let ticket: undefined | PaperlessTicketModel = undefined;
    if(model.isAttachedToTicket){
        ticket = PaperlessTicketStore.get(model.paperless_ticket_id);
    }

    if(!model.isAttachedToTicket){
        return (
            <LaunchNowButton model={model} size={'large'}/>
        )
    }

    console.log(model.hot_job_toggling)

    return (
        <Box display={'flex'}>
            <ModelActionButton
                name={'toggleHotJob'}
                text={model.is_hot_job ? 'Clear hot order' : 'Set hot order'}
                variant={model.is_hot_job ? 'outlined' : 'contained'}
                color={'primary'}
                size={'large'}
                disabled={ticket?.releasing || model.hot_job_toggling}
                startIcon={<FontAwesomeIcon size={'sm'} icon={faFire}/>}
                successHandler={() => {
                        enqueueSnackbar(model.is_hot_job ? 'Clear hot order requested.' : 'Set hot order requested.', { variant: 'success' });
                    }
                }
            />
            <Box ml={1}>
                <ModelActionButton
                    name={'findMyJob'}
                    text={'Find my order'}
                    variant={'contained'}
                    color={'primary'}
                    size={'large'}
                    disabled={ticket?.releasing || model.viewModel.is_hot_job || model.hot_job_toggling}
                    startIcon={<Search/>}
                    successHandler={() => {
                            enqueueSnackbar(`Find my order requested.`, { variant: 'success' });
                        }
                    }
                />
            </Box>
        </Box>
    )
})
