import Box from "@material-ui/core/Box";
import * as React from "react";
import {makeStyles, Typography} from "@material-ui/core";
import {blue, green, grey, red} from "@material-ui/core/colors";
import classNames from "classnames";
import {observer} from "mobx-react-lite";
import {PaperlessApiTransactionModel} from "../../stores/PaperlessApiTransactionStore";
import {
    AddBoxOutlined,
    Check,
    Close,
    Publish
} from "@material-ui/icons";

type TransactionStateBadgeProps = {
    model: PaperlessApiTransactionModel;
    showFailedDetails: boolean;
}

const useStyles = makeStyles((theme) => ({
    queued: {
        color: grey[600]
    },
    ongoing: {
        color: blue[600]
    },
    completed: {
        color: green[600]
    },
    failed : {
        color: red[600],
    },
    canceled : {
        color: grey[600]
    },
    hideOverflow: {
        overflow: "hidden",
        textOverflow: "ellipsis"
    }
}));


export const TransactionStateBadge: React.FunctionComponent<TransactionStateBadgeProps> = observer(({model, showFailedDetails=false}) => {
    const classes = useStyles();

    const stateClass = {
        queued: classes.queued,
        ongoing: classes.ongoing,
        completed: classes.completed,
        failed: classes.failed,
        canceled: classes.canceled
    }[model.state as 'queued' | 'ongoing' | 'completed' | 'failed' | 'canceled'];

    const stateIcon = {
        queued: <AddBoxOutlined/>,
        ongoing: <Publish/>,
        completed: <Check/>,
        failed: <Close/>,
        canceled: <Close/>
    }[model.state as 'queued' | 'ongoing' | 'completed' | 'failed' | 'canceled'];

    const showErrorDetails = showFailedDetails && model.transaction_error !== null

    return (
        <Box display={'flex'} alignItems={'center'} className={classNames(stateClass)}>
            {stateIcon}
            <Box ml={1} fontWeight={'bold'}>
                {model.state}
            </Box>
            {
                showErrorDetails &&
                <Box ml={0.5}>
                    <Typography variant={"caption"} className={classes.hideOverflow}>{`(${model.transaction_error})`}</Typography>
                </Box>
            }
        </Box>
    )
});

