import * as React from 'react';
import {observer} from "mobx-react-lite";
import {CircularProgress, Grid, makeStyles, Typography} from "@material-ui/core";
import {PaperlessTicketStore} from "../../stores/PaperlessTicketStore";
import {ButtonField} from "@rx-suite/ui";
import RefreshIcon from "@material-ui/icons/Refresh";
import {t} from "@lingui/macro";

const useStyles = makeStyles((theme) => ({
    wrapper: {
      width: 'fit-content'
    },
    field: {
        width: 'fit-content',
        margin: '0px 16px',
        textAlign: 'center'
    },
    fieldTitle: {
        fontSize: '1.1rem',
        marginBottom: '-8px',
        fontWeight: 'bold'
    }
}));

export const PaperlessTicketCountCard: React.FunctionComponent = observer(() => {
    const classes = useStyles();

    const fields = [
        {label: 'Available', key: 'available'},
        {label: 'Staged', key: 'staged'},
        {label: 'In Use', key: 'in_use'},
        {label: 'Total', key: 'total'}
    ]

    React.useEffect(() => {
        getTickets()
    }, [])

    const getTickets = async () => {
        try {
            await PaperlessTicketStore.refreshTicketCounts();
        } catch (e) {
            console.error(e);
        }
    }

    if(PaperlessTicketStore.fetchingStats){
        return (
            <Grid className={classes.wrapper} container alignItems={'center'}>
                <CircularProgress/>
            </Grid>
        )
    }

    return(
        <Grid container className={classes.wrapper}>
            {
                fields.map(field => {
                    return (
                        <Grid container item alignItems={'center'} direction={'column'} className={classes.field} >
                            <Typography className={classes.fieldTitle}>{field.label}</Typography>
                            <Typography>{PaperlessTicketStore.ticketCounts[field.key]}</Typography>
                        </Grid>
                    )
                })
            }
            <Grid item justifyContent={'center'}>
                <ButtonField
                    text={t`Refresh Stats`}
                    onClick={getTickets}
                    startIcon={<RefreshIcon/>}
                />
            </Grid>
        </Grid>
    )
})

