import * as React from 'react';
import {observer} from "mobx-react-lite";
import {useSnackbar} from "notistack";
import {PaperlessTicketStore} from "../../stores/PaperlessTicketStore";
import {t} from "@lingui/macro";
import {SearchRounded} from "@material-ui/icons";
import {useHistory} from "react-router-dom";
import {ScannerFieldWithButton} from "../generic/ScannerFieldWithButton";
import {useContext} from "react";
import {OpenDialogContext} from "../../pages/paperless_tickets/PaperlessTicketBreadModel";

export const TicketBarcodeScanField: React.FunctionComponent = observer((props) => {
    const {enqueueSnackbar} = useSnackbar();
    const history = useHistory();

    const {bulkAddDialogOpen} = useContext(OpenDialogContext);

    const [ticketBarcode, setTicketBarcode] = React.useState<string>("");
    const [scanning, setScanning] = React.useState(false);

    const handleChange = React.useCallback((e: any) => {
        setTicketBarcode(e.target.value)
    }, []);

    const handleScan = React.useCallback(async (barcode: string) => {
        // Because the dialog is on the same page, this field is technically still in focus so register hand-held scanner events
        if(bulkAddDialogOpen){
            return;
        }

        barcode = barcode.toUpperCase();

        setScanning(true)

        try {
            const model = await PaperlessTicketStore.findByBarcode(barcode);

            if(!model) {
                enqueueSnackbar(t`Cannot find e-ticket with barcode ${barcode}`, {variant: 'error'})
            } else {
                enqueueSnackbar(t`e-ticket found`, {variant: 'success'})
                history.push(`/paperless_tickets/${model.id}/read`);
            }
        } catch (e) {
            console.error(e);
            enqueueSnackbar(t`An issue while fetching e-ticket with barcode ${barcode}`, {variant: "error"})
        }

        setTicketBarcode("");
        setScanning(false);
    }, [bulkAddDialogOpen]);

    return (
        <React.Fragment>
            <ScannerFieldWithButton
                scannerConfig={{
                    inputConfig: {
                        label: t`E-Ticket Barcode`,
                        value: ticketBarcode,
                        onChange: handleChange,
                        disabled: bulkAddDialogOpen,
                        autoFocus: true
                    },
                    scanConfig: {
                        onComplete: () => handleScan(ticketBarcode),
                        minLength: 4,
                        averageWaitTime: 20
                    }
                }}
                buttonConfig={{
                    text: t`Search`,
                    variant: 'contained',
                    color: 'secondary',
                    startIcon: <SearchRounded/>,
                    disabled: ticketBarcode === "",
                    onClick: () => handleScan(ticketBarcode),
                    loading: scanning
                }}
            />
        </React.Fragment>
    )
})