import Box from "@material-ui/core/Box";
import * as React from "react";
import {alpha, makeStyles} from "@material-ui/core";
import {blue, green, grey} from "@material-ui/core/colors";
import Typography from "@material-ui/core/Typography";
import classNames from "classnames";
import {observer} from "mobx-react-lite";
import {PaperlessTicketModel} from "../../stores/PaperlessTicketStore";

type TicketStatusBadgeProps = {
    model: PaperlessTicketModel
}

const useStyles = makeStyles((theme) => ({
    wrapper: {
        width: 'fit-content',
        height: 'fit-content',
        padding: '1px 12px',
        borderWidth: '1px',
        borderStyle: 'solid',
        borderRadius: '3px'
    },
    available: {
        backgroundColor: alpha(green[600], 0.1),
        borderColor: green[600],
        color: green[600]
    },
    staged: {
        backgroundColor: alpha(blue[600], 0.1),
        borderColor: blue[600],
        color: blue[600]
    },
    inUse : {
        backgroundColor: alpha(grey[600], 0.1),
        borderColor: grey[600],
        color: grey[600]
    }
}));


export const TicketStatusBadge: React.FunctionComponent<TicketStatusBadgeProps> = observer(({model}) => {
    const classes = useStyles();

    const statusClass = () => {
        if(model.isStaged){
            return classes.staged;
        }
        if(model.isAttached){
            return classes.inUse;
        }
        return classes.available;
    }

    return (
        <Box className={classNames(classes.wrapper, statusClass())}>
            <Typography>{model.state}</Typography>
        </Box>
    );
});

