import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ButtonField, useFlag, useModelContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {PaperlessTicketModel} from "../../../stores/PaperlessTicketStore";
import Delete from "@material-ui/icons/Delete";
import {makeStyles} from "@material-ui/core";
import {useSnackbar} from "notistack";
import {WarningDialog} from "../../generic/WarningDialog";
import {useHistory} from "react-router-dom";

const useStyles = makeStyles(theme => ({
    danger: {
        backgroundColor: theme.palette.error.main
    }
}));

export const DeleteTicketButton: React.FunctionComponent = observer(() => {
    const ticketModel = useModelContext() as PaperlessTicketModel;
    const classes = useStyles();
    const {enqueueSnackbar} = useSnackbar();
    const history = useHistory();

    const [isLoading, setIsLoading] = React.useState<boolean>(false);
    const [confirmOpen, handleOpenConfirm, handleCloseConfirm] = useFlag();

    const handleDelete = React.useCallback(async () => {
        handleCloseConfirm();
        setIsLoading(true);
        try {
            await ticketModel.delete();
            history.replace(`/paperless_tickets`);
        } catch (e) {
            console.error(e);
            enqueueSnackbar(t`An error occurred while deleting.`, {variant: 'error'});
        }
        setIsLoading(false);
    }, [enqueueSnackbar, ticketModel]);

    return (
        <React.Fragment>
            <ButtonField
                text={t`Delete`}
                onClick={handleOpenConfirm}
                loading={isLoading}
                variant={'contained'}
                disabled={!ticketModel.canDelete()}
                className={classes.danger}
                startIcon={<Delete/>}
            />
            <WarningDialog
                warningMessage={t`This action will delete this ticket and make it unavailable for any further actions.`}
                open={confirmOpen}
                onConfirm={handleDelete}
                handleClose={handleCloseConfirm}
                critical
           />
        </React.Fragment>
    )
})