import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ButtonField, useFlag, useModelContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {PaperlessTicketModel} from "../../../stores/PaperlessTicketStore";
import {useSnackbar} from "notistack";
import {WarningDialog} from "../../generic/WarningDialog";
import {Clear} from "@material-ui/icons";

export const ReleaseTicketButton: React.FunctionComponent = observer(() => {
    const ticketModel = useModelContext() as PaperlessTicketModel;
    const {enqueueSnackbar} = useSnackbar();

    const [isLoading, setIsLoading] = React.useState<boolean>(false);
    const [confirmOpen, handleOpenConfirm, handleCloseConfirm] = useFlag();

    const handleRelease = React.useCallback(async () => {
        handleCloseConfirm();
        setIsLoading(true);
        try {
            await ticketModel.release();
            enqueueSnackbar(`Ticket release requested.`, { variant: 'success' });
        } catch (e) {
            console.error(e);
            enqueueSnackbar(t`An error occurred while requesting release.`, {variant: 'error'});
        }
        setIsLoading(false);
    }, [enqueueSnackbar, ticketModel]);

    return (
        <React.Fragment>
            <ButtonField
                text={t`Release`}
                onClick={handleOpenConfirm}
                loading={isLoading}
                variant={'contained'}
                disabled={!ticketModel.isAttached || ticketModel.viewModel.releasing}
                startIcon={<Clear/>}
            />
            <WarningDialog
                warningMessage={t`This action will clear order ${ticketModel.order_number} that is currently attached to this ticket.`}
                open={confirmOpen}
                onConfirm={handleRelease}
                handleClose={handleCloseConfirm}
                critical
           />
        </React.Fragment>
    )
})