import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ModelActionButton, useModelContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {PaperlessTicketModel} from "../../../stores/PaperlessTicketStore";
import {faAngleDoubleDown, faAngleDoubleUp} from "@rx-suite/pro-solid-svg-icons";
import {makeStyles} from "@material-ui/core";
import {SettingStore} from "../../../stores/SettingStore";

const useStyles = makeStyles((theme) => ({
    button: {
        width: '110px'
    }
}));

export const ToggleStageTicketButton: React.FunctionComponent = observer(() => {
    const classes = useStyles();
    const ticketModel = useModelContext() as PaperlessTicketModel;

    if(SettingStore.selectedModel?.isManualPairingMode) {
        return null;
    }

    return (
        <ModelActionButton
            name={'toggleStaged'}
            text={ticketModel.isStaged ? t`Un-Stage` : t`Stage`}
            className={classes.button}
            variant={'contained'}
            color={'primary'}
            disabled={ticketModel.isAttached}
            startIcon={ticketModel.isStaged ? <FontAwesomeIcon icon={faAngleDoubleDown}/> : <FontAwesomeIcon icon={faAngleDoubleUp}/>}
        />
    )
})