import React, {useMemo} from "react";
import {observer} from "mobx-react-lite";
import {makeColumn, ModelDialogTable, ModelInput, useModelContext} from "@rx-suite/ui";
import {PaperlessTicketModel} from "../../../stores/PaperlessTicketStore";
import {TicketStaticDatumStore} from "../../../stores/TicketStaticDatumStore";
import {t} from "@lingui/macro";
import {Model} from "@rx-suite/data";

export const TicketStaticDataModelTable: React.FunctionComponent = observer(() => {
    const model = useModelContext() as PaperlessTicketModel;

    const columns = useMemo(() => {
        return [
            makeColumn('name', t`Name`, 'string'),
            makeColumn('value', t`Value`, 'string')
        ]
    },[])

    const dialogForm = (m: Model) => {
        if(m.isNew) {
            m.viewModel.paperless_ticket_id = model.getId();
        }

        return <React.Fragment>
            <ModelInput
                label={t`Field Name`}
                name={'name'}
                hint={
                    {
                        title: t`Static Field Name`,
                        text: t`The field name to be identify this data in the ticket templates.`
                    }
                }
            />
            <ModelInput name={'value'}/>
        </React.Fragment>
    }

    return <ModelDialogTable
        store={TicketStaticDatumStore}
        columns={columns}
        tableProps={
            {
                defaultFiltered: [{id: 'paperless_ticket_id', value: model.getId()}],
                noLinkColumns: ['name', 'value']
            }
        }
        dialogProps={
            {
                dialogTitle: t`Add Static Data`,
                dialogForm: dialogForm
            }
        }
        createButtonProps={
            {
                text: t`Add Static Data`
            }
        }

    />
})