import * as React from "react";
import {observer} from "mobx-react-lite";
import Box from "@material-ui/core/Box";
import {Grid, makeStyles, Paper} from "@material-ui/core";
import Typography from "@material-ui/core/Typography";
import {t} from "@lingui/macro";
import {TicketStatusBadge} from "../TicketStatusBadge";
import {Conditional, useModelContext} from "@rx-suite/ui";
import {PaperlessTicketButtonsBar} from "../buttons/PaperlessTicketButtonsBar";
import {PaperlessTicketForceActionBar} from "../buttons/PaperlessTicketForceActionBar";
import {PaperlessTicketModel} from "../../../stores/PaperlessTicketStore";
import {TicketCurrentDisplay} from "../../../pages/order_records/form/tabs/TicketCurrentDisplay";

const useStyles = makeStyles((theme) => ({
    headerBar: {
        display: 'flex'
    }
}))

export const PaperlessTicketHeader: React.FunctionComponent = observer(() => {
    const classes = useStyles();

    const model = useModelContext() as PaperlessTicketModel;

    return (
        <Box display={'flex'} alignItems={'flex-start'} justifyContent={'space-between'}>
            <Box display={'flex'}>
                <Box mr={4}>
                    <TicketCurrentDisplay ticket={model}/>
                </Box>
                <Box>
                    <Grid container justifyContent={'space-between'}>
                        <Box className={classes.headerBar}>
                            <Paper variant={'outlined'}>
                                <Box p={3}>
                                    <Box display={'flex'} alignItems={'center'}>
                                        <Typography variant={'h4'} >{t`Ticket ${model.ticket_barcode}`}</Typography>
                                        <Box ml={1}>
                                            <TicketStatusBadge model={model}/>
                                        </Box>
                                    </Box>
                                    <Conditional condition={model.isAttached}>
                                        <Box mt={-1}>
                                            <Typography variant={'h6'}>{t`Attached to order ${model.order_number}`}</Typography>
                                        </Box>
                                    </Conditional>
                                </Box>
                            </Paper>
                            <PaperlessTicketButtonsBar model={model}/>
                        </Box>
                    </Grid>
                </Box>
            </Box>
            <Box display={'flex'}>
                <PaperlessTicketForceActionBar model={model}/>
            </Box>
        </Box>
    )
})
