import * as React from "react";
import {Box, makeStyles} from "@material-ui/core";
import {observer} from "mobx-react-lite";
import classnames from "classnames";
import ReactTable, {Column} from "react-table";
import {
    PaperlessApiTransactionModel,
    PaperlessApiTransactionStore
} from "../../../../stores/PaperlessApiTransactionStore";
import {useEffect, useMemo, useState} from "react";
import {DataStore} from "@rx-suite/data";

type AsyncBulkActionResultsProps = {
    transactionIds: string[];
    columns: Column[];
}

const useStyles = makeStyles((theme) => ({
    wrapper: {
        flexGrow: 1,
        display: 'flex',
        alignItems: "flex-end"
    },
    table: {
        height: '600px'
    }
}));

export const AsyncBulkActionResults: React.FunctionComponent<AsyncBulkActionResultsProps> = observer(({transactionIds, columns}) => {
    const classes = useStyles();

    const [isLoading, setIsLoading] = React.useState<boolean>(false);

    const clonedPaperlessApiStore = useMemo(() => {
        return PaperlessApiTransactionStore.clone() as DataStore<PaperlessApiTransactionModel>;
    }, [transactionIds])

    useEffect(() => {
        const exec = async () => {
            setIsLoading(true);

            if(transactionIds.length > 0) {
                await clonedPaperlessApiStore.getByIdsAndSubscribe(transactionIds);
            }

            setIsLoading(false);
        }

        exec();
    }, [transactionIds])

    return (
        <Box className={classes.wrapper}>
            <ReactTable
                data={clonedPaperlessApiStore.models}
                columns={columns}
                sortable={false}
                showPagination={true}
                className={classnames(classes.table, '-striped')}
                style={{flexGrow: 1}}
                loading={isLoading}
            />
        </Box>
    );
});

