import {observer} from "mobx-react-lite";
import * as React from "react";
import {ButtonField} from "@rx-suite/ui";
import Box from "@material-ui/core/Box";
import ReactTable, {Column} from "react-table";
import classnames from "classnames";
import {IconButton, makeStyles} from "@material-ui/core";
import {Delete} from "@material-ui/icons";

type BulkAddItemTableProps = {
    submitText: string;
    handleSubmit: () => void
    isLoading: boolean;
    data: BulkAddRecord[];
    setData:  React.Dispatch<React.SetStateAction<BulkAddRecord[]>>;
    columns: Column[]
}


const useStyles = makeStyles((theme) => ({
    clearButton: {
        color: theme.palette.error.main
    },
    table: {
        height: '600px'
    }
}));

export const BulkAddTable: React.FunctionComponent<BulkAddItemTableProps> = observer(({
                                                                                            submitText,
                                                                                            handleSubmit,
                                                                                            isLoading,
                                                                                            data,
                                                                                            setData,
                                                                                            columns
                                                                                          }) => {
    const classes = useStyles();

    const removeFromBulkList = React.useCallback((indexToRemove: number) => {
        const newArr = data.filter((item, index) => index !== indexToRemove)
        setData(newArr)
    }, [data, setData])

    const resolvedColumns = React.useMemo(() => {
        const defaultColumns =  [{
            accessor: (entry: {value: string}) => entry,
            id: '_actions',
            width: 50,
            Cell: (cellInfo: { index: number }) => {
                return (
                    <IconButton size={'small'} onClick={() => removeFromBulkList(cellInfo.index)}>
                        <Delete className={classes.clearButton}/>
                    </IconButton>
                )
            }
        }] as Column[];

        return defaultColumns.concat(columns);
    }, [columns])

    return (
        <React.Fragment>
            <Box flexGrow={1}>
                <ButtonField
                    text={submitText}
                    color={'secondary'}
                    size={'large'}
                    disabled={data.length === 0}
                    onClick={handleSubmit}
                    loading={isLoading}
                />
                <ButtonField
                    text={'Clear All'}
                    color={'primary'}
                    size={'large'}
                    disabled={data.length === 0}
                    onClick={() => setData([])}
                    loading={isLoading}
                />
                <ReactTable
                    data={data}
                    columns={resolvedColumns}
                    sortable={false}
                    showPagination={true}
                    className={classnames(classes.table, '-striped')}
                />
            </Box>
        </React.Fragment>
    );
});

export type BulkAddRecord = {
    status?: any;
    [key:string]: string;
}