import * as React from "react";
import {observer} from "mobx-react-lite";
import {BaseButtonField, CheckboxField, ModelInput, ModelSelect, useModelContext} from "@rx-suite/ui";
import {BLINK_SPEED_OPTIONS, LED_COLOR_OPTIONS} from "../../../stores/SettingStore";
import {QueryBuilder} from "./QueryBuilder";
import {OrderFindQueryModel} from "../../../stores/OrderFindQueryStore";
import {useCallback, useState} from "react";
import {t} from "@lingui/macro";
import {red} from "@material-ui/core/colors";
import {createStyles, makeStyles} from "@material-ui/core";

type OrderFindQueryFormTabProps = {
    handleClose: () => void
}

const useStyles = makeStyles(() =>
    createStyles({
        deleteButton: {
            "&.MuiButton-containedPrimary:hover": {
                backgroundColor: red[800],
            },
            backgroundColor: red[500]
        }
    })
);

export const OrderFindQueryFormTab: React.FunctionComponent<OrderFindQueryFormTabProps> = observer(({handleClose}) => {
    const classes = useStyles();

    const model = useModelContext() as OrderFindQueryModel;

    const [checked, setChecked] = useState(!!model.viewModel.blink_duration);

    const deleteOnClick = useCallback(async () => {
        await model.delete();
        handleClose();
    }, [model])

    return <React.Fragment>
        <ModelInput name={'name'}/>
        <ModelSelect name={'color'} options={LED_COLOR_OPTIONS}/>
        <ModelSelect name={'blink_pattern'} options={BLINK_SPEED_OPTIONS}/>
        <CheckboxField label={t`Stop blinking after set duration?`} checked={checked} onChange={() => setChecked((prevState) => !prevState)}/>
        {checked &&
            <ModelInput name={'blink_duration'}/>}
        <QueryBuilder model={model}/>
        {!model.isNew &&
            <BaseButtonField text={t`Delete Query`} variant={'contained'} classes={{root: classes.deleteButton}} onClick={deleteOnClick} loading={model.updating}/>
        }
    </React.Fragment>
})
