import * as React from "react";
import {observer} from "mobx-react-lite";
import {makeColumn, ModelTable, useModelContext} from "@rx-suite/ui";
import {OrderFindQueryModel} from "../../../stores/OrderFindQueryStore";
import {PaperlessApiTransactionStore} from "../../../stores/PaperlessApiTransactionStore";
import {useMemo} from "react";
import {t} from "@lingui/macro";
import {useStateColumn} from "../../../hooks/table_columns/api_transactions/useStateColumn";
import {makeStyles} from "@material-ui/core";

const useStyles = makeStyles(() => ({
    tableBody: {
        "& .rt-tbody": {
            height: 315
        }
    }
}));

export const OrderFindQueryResultsTab: React.FunctionComponent = observer(() => {
    const classes = useStyles();
    const model = useModelContext() as OrderFindQueryModel;

    const columns = useMemo(() => {
        return [
            makeColumn('associated_ticket_barcode', t`Ticket Barcode`, 'string'),
            makeColumn('associated_order_number', t`Ticket Barcode`, 'string'),
            useStateColumn()
        ]
    }, []);

    return <ModelTable
        store={PaperlessApiTransactionStore}
        columns={columns}
        defaultFiltered={[{id: 'order_find_query_id', value: model.getId(), persistent: true}]}
        suppressWrapper={true}
        suppressActionColumn={true}
        suppressUserDefaults={true}
        fixedHeight={true}
        className={classes.tableBody}
        rememberFetchParams={true}
    />
})
