import * as React from "react";
import {observer} from "mobx-react-lite";
import {OrderFindQueryModel} from "../../../stores/OrderFindQueryStore";
import Box from "@material-ui/core/Box";
import {ButtonField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {useSnackbar} from "notistack";
import {createStyles, makeStyles} from "@material-ui/core";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faEye, faPlay, faStop} from "@rx-suite/pro-solid-svg-icons";
import {green, red} from "@material-ui/core/colors";

type QueryActionsProps = {
    orderQueryModel: OrderFindQueryModel;
    handleEdit: (orderQueryModel: OrderFindQueryModel) => void;
    handleStop: () => void;
}

const useStyles = makeStyles(() =>
    createStyles({
        executeButton: {
            "&.MuiButton-containedPrimary:hover": {
                backgroundColor: green[800],
            },
            "&.MuiButton-contained.Mui-disabled": {
                backgroundColor: green[100]
            },
            backgroundColor: green[500]
        },
        stopButton: {
            "&.MuiButton-containedPrimary:hover": {
                backgroundColor: red[800],
            },
            "&.MuiButton-contained.Mui-disabled": {
                backgroundColor: red[50]
            },
            backgroundColor: red[400]
        }
    })
);


export const QueryActions: React.FunctionComponent<QueryActionsProps> = observer(({orderQueryModel, handleEdit}) => {
    const {enqueueSnackbar} = useSnackbar();
    const classes = useStyles();

    const execute = async () => {
        const data = await orderQueryModel.execute();

        if(data.error) {
            enqueueSnackbar(data.error, {variant: 'error'});
        } else {
            enqueueSnackbar(t`Query request executed`, {variant: 'success'})
        }
    }

    const stop = async () => {
        const data = await orderQueryModel.stop();

        if(data.error) {
            enqueueSnackbar(t`There was a problem stopping the query`, {variant: 'error'});
        } else {
            enqueueSnackbar(t`Query request stopped`, {variant: 'success'})
        }
    }

    return <Box>
        <ButtonField
            text={t`Execute`}
            startIcon={<FontAwesomeIcon icon={faPlay}/>}
            onClick={execute}
            loading={orderQueryModel.updating}
            disabled={!orderQueryModel.canExecute}
            classes={{root: classes.executeButton}}
        />
        <ButtonField
            text={t`Stop`}
            startIcon={<FontAwesomeIcon icon={faStop}/>}
            onClick={stop}
            loading={orderQueryModel.updating}
            disabled={!orderQueryModel.canStop}
            classes={{root: classes.stopButton}}
        />
        <ButtonField
            text={t`View`}
            startIcon={<FontAwesomeIcon icon={faEye}/>}
            onClick={() => handleEdit(orderQueryModel)}
        />
    </Box>
})