import Box from "@material-ui/core/Box";
import * as React from "react";
import {alpha, makeStyles} from "@material-ui/core";
import {blue, green, red} from "@material-ui/core/colors";
import Typography from "@material-ui/core/Typography";
import classNames from "classnames";
import {observer} from "mobx-react-lite";
import {queryStatus} from "../../../stores/OrderFindQueryStore";

type QueryStatusBadgeProps = {
    status: queryStatus
}

const useStyles = makeStyles((theme) => ({
    wrapper: {
        width: 'fit-content',
        height: 'fit-content',
        padding: '1px 12px',
        borderWidth: '1px',
        borderStyle: 'solid',
        borderRadius: '3px'
    },
    ready: {
        backgroundColor: alpha(green[600], 0.1),
        borderColor: green[600],
        color: green[600]
    },
    searching: {
        backgroundColor: alpha(blue[300], 0.1),
        borderColor: blue[300],
        color: blue[300]
    },
    running: {
        backgroundColor: alpha(blue[600], 0.1),
        borderColor: blue[600],
        color: blue[600]
    },
    stopping: {
        backgroundColor: alpha(red[600], 0.1),
        borderColor: red[600],
        color: red[600]
    }
}));

export const QueryStatusBadge: React.FunctionComponent<QueryStatusBadgeProps> = observer(({status}) => {
    const classes = useStyles();

    return (
        <Box className={classNames(classes.wrapper, classes[status])}>
            <Typography variant={'h6'}>{status}</Typography>
        </Box>
    );
});

