import * as React from 'react';
import {t} from "@lingui/macro";
import {PaperlessApiTransactionModel, PaperlessApiTransactionState, paperlessApiTransactionStates} from "../../../stores/PaperlessApiTransactionStore";
import {TransactionStateBadge} from "../../../components/paperless_api_transactions/TransactionStateBadge";
import {SelectField} from "@rx-suite/ui";
import {Filter, ReactTableFunction} from "react-table";

export const useStateColumn = (allowFilter:boolean=true, showFailedDetails=false) => {

    return {
        Header: t`Transaction State`,
        accessor: (transaction: PaperlessApiTransactionModel) => transaction,
        id: 'state',
        filterable: allowFilter,
        Filter: ({ filter, onChange }: { filter: Filter, onChange: ReactTableFunction }) => (
            <SelectField
                options={paperlessApiTransactionStates}
                onChange={(name, value: PaperlessApiTransactionState) => {
                    onChange(value);
                }}
                value={filter ? filter.value : ""}
                clearable
            />
        ),
        Cell: (cellInfo: { value: PaperlessApiTransactionModel }) => {
            return (
                <TransactionStateBadge model={cellInfo.value} showFailedDetails={showFailedDetails}/>
            )
        }
    };
}
