import React from "react";
import {PaperlessApiTransactionStore} from "../stores/PaperlessApiTransactionStore";

export const useTransactionResults = (defaultValue: string[]): [string[], (values: string[]) => void] => {
    const [transactionIds, setTransactionIds] = React.useState<string[]>(defaultValue);

    const handleSetTransactionIds = (values: string[]): void  => {
        setTransactionIds((oldIds) => {

            const notCompletedIds = PaperlessApiTransactionStore.models
                .filter(model => transactionIds.includes(model.getId()))
                .filter(model => !model.isComplete)
                .map(model => model.getId());

            const notCompletedOldIds = notCompletedIds.filter(tId => oldIds.includes(tId));

            // Do not remove NEW ids even if they are completed already
            // we want the user to see that they have been completed before removing
            return notCompletedOldIds.concat(values);
        })
    }

    return [transactionIds, handleSetTransactionIds];
}