import * as React from 'react';
import {alpha, Box, Grid, makeStyles} from "@material-ui/core";
import {t} from "@lingui/macro";
import {BreadModel, makeFormattedDateTimeColumn, PaddedPaper} from "@rx-suite/ui";
import {OrderRecordModel, OrderRecordStore} from "../../../stores/OrderRecordStore";
import {OrderRecordForm} from "../form/OrderRecordForm";
import {JobScannerField} from "../../../components/order_records/JobScannerField";
import {HotJobBadge} from "../../../components/order_records/HotJobBadge";
import {red} from "@material-ui/core/colors";
import {TicketTemplateStore} from "../../../stores/TicketTemplateStore";
import {useEffect} from "react";

const useStyles = makeStyles((theme) => ({
    hotJob: {
        color: red[300],
        border: `solid 1px ${red[300]}`,
        backgroundColor: alpha(red[200], 0.1),
        borderRadius: '4px'
    }
}));

export const LiveOrderRecordsBreadModel = () => {
    const classes = useStyles();

    TicketTemplateStore.getAll();

    useEffect(() => {
        OrderRecordStore.setFetchParams({
            page: 0,
            limit: 10,
            sorted: [{id: "entry_time", desc: true}],
            filtered: [{id: 'state', value: 'launched'}]
        })
    }, []);

    const columns = React.useMemo(() => {
        return [
            {
                Header: t`Hot Job?`,
                accessor: (orderRecord: OrderRecordModel) => orderRecord,
                id: 'is_hot_job',
                width: 100,
                Cell: (cellInfo: {value: OrderRecordModel }) => {
                    if(cellInfo.value.is_hot_job){
                        return (
                            <Grid className={classes.hotJob} container justifyContent={'center'}>
                                <HotJobBadge size={'sm'}/>
                            </Grid>
                        )
                    }else{
                        return null;
                    }
                }
            },
            {
                Header: t`Order Number`,
                accessor: 'number',
                id: 'order_number',
                sortable: true,
                filterable: true,
                maxWidth: 250
            },
            {
                Header: t`E-Ticket Barcode`,
                accessor: 'paperless_ticket_barcode',
                id: 'paperless_ticket_barcode',
                sortable: true,
                filterable: true,
                maxWidth: 250
            },
            {
                Header: t`Current Template`,
                accessor: (model: OrderRecordModel) => model,
                id: 'ticket_template_id',
                Cell: (cellInfo: {value: OrderRecordModel}) => {
                    const template = TicketTemplateStore.models.find(template => Number(template.getId()) === cellInfo.value.ticket_template_id)

                    if (!template) {
                        return null;
                    }

                    return template.process_name;
                }
            },
            makeFormattedDateTimeColumn('last_action_time', t`Last Write Time`, "dateTime")
        ];
    }, [TicketTemplateStore.models]);

    return (
        <React.Fragment>
            <Box mb={2} pt={2}>
                <JobScannerField/>
            </Box>
            <PaddedPaper>
                <BreadModel
                    store={OrderRecordStore}
                    Form={OrderRecordForm}
                    columns={columns}
                    mountCreate={false}
                    mountEdit={false}
                    tableProps={
                        {
                            suppressWrapper: true,
                            showCreateButton: false,
                            defaultSorted:[{id: "entry_time", desc: true}],
                            replacementActions: {
                                Edit: () => null,
                                Delete: () => null
                            },
                            defaultFiltered: [{id: 'state', value: 'launched'}],
                            rememberFetchParams: false
                        }
                    }
                />
            </PaddedPaper>
        </React.Fragment>
    );
};
