import * as React from "react";
import {observer} from "mobx-react-lite";
import {Conditional, FormProps, IfTrue, ModelProvider, TabsContainer} from "@rx-suite/ui";
import {OrderRecordModel} from "../../../stores/OrderRecordStore";
import {Box, Grid, LinearProgress} from "@material-ui/core";
import {t} from "@lingui/macro";
import {OrderRecordData} from "./tabs/OrderRecordData";
import {OrderRecordEventsBreadModel} from "./tabs/OrderRecordTransactions";
import {OrderRecordHeader} from "../../../components/order_records/toolbar/OrderRecordHeader";
import {PaperlessTicketModel, PaperlessTicketStore} from "../../../stores/PaperlessTicketStore";
import Alert from "@material-ui/lab/Alert";

type OrderRecordFormProps = {
    model: OrderRecordModel;
} & Omit<FormProps, 'model'>

export const OrderRecordForm: React.FunctionComponent<OrderRecordFormProps> = observer(({model}) => {
    let ticket: undefined | PaperlessTicketModel = undefined;
    if(model.isAttachedToTicket){
        ticket = PaperlessTicketStore.get(model.paperless_ticket_id);
    }

    if(model.isAttachedToTicket && ticket == undefined) {
        return <LinearProgress/>
    }

    return (
        <ModelProvider value={model}>
            <Conditional condition={!!ticket?.releasing}>
                <IfTrue>
                    <Alert severity="warning">{t`The Ticket attached to this Order is being released, some functionality may be disabled.`}</Alert>
                </IfTrue>
            </Conditional>
            <Box p={2} display={'flex'} flexDirection={'column'} justifyContent={'start'} alignItems={'flex-start'}>
                <Box width={'100%'}>
                    <OrderRecordHeader />
                </Box>
                <Grid container>
                    {model.isAttachedToTicket && <Box mt={3} width={'100%'}>
                        <TabsContainer tabs={[
                            {
                                label: t`Event Log`,
                                component: <OrderRecordEventsBreadModel/>,
                            },
                            {
                                label: t`Order Data`,
                                component: <OrderRecordData/>,
                            }
                        ]}/>
                    </Box>}
                </Grid>
            </Box>
        </ModelProvider>
    )



})
