import * as React from 'react';
import {observer} from "mobx-react-lite";
import {useModelContext} from "@rx-suite/ui";
import {OrderRecordModel} from "../../../../stores/OrderRecordStore";
import {PaperlessTicketModel} from "../../../../stores/PaperlessTicketStore";
import {Box, CircularProgress, makeStyles} from "@material-ui/core";
import Typography from "@material-ui/core/Typography";
import {InlineWarning} from "../../../../components/generic/InlineWarning";
import {t} from "@lingui/macro";

type TicketCurrentDisplayProps = {
    ticket: PaperlessTicketModel;
}

const useStyles = makeStyles(theme => ({
    wrapper: {
        width: '350px',
        height: '200px',
        border: 'solid 1px black'
    }
}));

export const TicketCurrentDisplay: React.FunctionComponent<TicketCurrentDisplayProps> = observer(({ticket}) => {
    const order = useModelContext() as OrderRecordModel;
    const classes = useStyles();

    const [isLoading, setIsLoading] = React.useState<boolean>(true);
    const [imageBlob, setImageBlob] = React.useState<string|null>(null);

    React.useEffect(() => {
        setIsLoading(true);
        setImageBlob(null);

        const fetchImage = async () => {
            try {
                const resp = await (ticket as PaperlessTicketModel).fetchImage();
                setImageBlob(resp);
            } catch (e) {
                console.error(e);
            }
            setIsLoading(false);
        }

        fetchImage();
    }, [order.ticket_template_id]); // If the ticket_template_id changes, fetch the new image

    if(isLoading){
        return (
            <Box display={'flex'} justifyContent={'center'} alignItems={'center'} className={classes.wrapper}>
                <Box mr={1}>
                    <CircularProgress/>
                </Box>
                <Typography>Loading Image...</Typography>
            </Box>
        )
    }

    if(!imageBlob){
        return (
            <Box display={'flex'} justifyContent={'center'} alignItems={'center'} className={classes.wrapper}>
                <InlineWarning text={t`Image Unavailable`}/>
            </Box>
        )
    }

    return (
        <Box display={'flex'} justifyContent={'center'} alignItems={'center'} className={classes.wrapper}>
            <img src={imageBlob} alt={"Paperless Ticket Image"}/>
        </Box>
    );
});
