import * as React from 'react';
import {BreadModel, PaddedPaper, useFlag} from "@rx-suite/ui";
import {PaperlessTicketStore} from "../../stores/PaperlessTicketStore";
import {TicketBarcodeScanField} from "../../components/paperless_tickets/TicketBarcodeScanField";
import {Box} from "@material-ui/core";
import {observer} from "mobx-react-lite";
import {PaperlessTicketToolbar} from "../../components/paperless_tickets/toolbar/PaperlessTicketToolbar";
import {useShowAllTicketsColumns} from "../../hooks/table_columns/paperless_tickets/useShowAllTicketsColumns";
import {useShowStagedTicketsColumn} from "../../hooks/table_columns/paperless_tickets/useShowStagedTicketsColumn";
import {useShowAvailableTicketsColumns} from "../../hooks/table_columns/paperless_tickets/useShowAvailableTicketsColumns";
import {useShowInUseTicketsColumns} from "../../hooks/table_columns/paperless_tickets/useShowInUseTicketsColumns";
import {PaperlessTicketForm} from "./PaperlessTicketForm";
import {createContext} from "react";

export const OpenDialogContext: React.Context<any> = createContext(null);

export const PaperlessTicketBreadModel = observer(() => {
    const [bulkAddDialogOpen, handleOpenBulkAdd, handleCloseBulkAdd] = useFlag();

    const columns = React.useMemo(() => {
        switch(PaperlessTicketStore.ticketStateFilter){
            case 'available':
                return useShowAvailableTicketsColumns();
            case 'in_use':
                return useShowInUseTicketsColumns();
            case 'staged':
                return useShowStagedTicketsColumn();
        }
        return useShowAllTicketsColumns();
    }, [PaperlessTicketStore.ticketStateFilter]);

    return (
        <OpenDialogContext.Provider value={{
            bulkAddDialogOpen,
            handleOpenBulkAdd,
            handleCloseBulkAdd
        }}>
            <PaddedPaper>
                <TicketBarcodeScanField />
            </PaddedPaper>
            <Box mt={1} mb={1}/>
            <PaddedPaper>
                <BreadModel
                    store={PaperlessTicketStore}
                    Form={PaperlessTicketForm}
                    columns={columns}
                    mountCreate={false}
                    mountEdit={false}
                    tableProps={
                        {
                            suppressWrapper: true,
                            showCreateButton: false,
                            suppressActionColumn: true,
                            defaultFiltered: [{ id: 'state', value: PaperlessTicketStore.ticketStateFilter}],
                            preTableActions: <PaperlessTicketToolbar/>
                        }
                    }
                />
            </PaddedPaper>
        </OpenDialogContext.Provider>
    )
});
