import React from "react";
import {Conditional, FormProps, IfTrue, ModelProvider, TabsContainer} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {PaperlessTicketModel} from "../../stores/PaperlessTicketStore";
import {PaperlessTicketTransactionLog} from "../../components/paperless_api_transactions/PaperlessTicketTransactionLog";
import {t} from "@lingui/macro";
import Box from "@material-ui/core/Box";
import Alert from "@material-ui/lab/Alert";
import {PaperlessTicketHeader} from "../../components/paperless_tickets/toolbar/PaperlessTicketHeader";
import {TicketStaticDataModelTable} from "../../components/paperless_tickets/ticket_static_data/TicketStaticDataModelTable";

type PaperlessTicketFormProps = {
    model: PaperlessTicketModel
} & Omit<FormProps, 'model'>

export const PaperlessTicketForm: React.FunctionComponent<PaperlessTicketFormProps> = observer(({model}) => {

    return (
        <ModelProvider value={model}>
            <Conditional condition={model.releasing}>
                <IfTrue>
                    <Box mb={1}>
                        <Alert severity="warning">{t`This Ticket is in the process of being released, some functionality may be disabled`}</Alert>
                    </Box>
                </IfTrue>
            </Conditional>
            <PaperlessTicketHeader/>
            <Box mt={1}>
                <TabsContainer tabs={
                    [
                        {
                            label: t`Transactions`,
                            component: <PaperlessTicketTransactionLog modelId={Number(model.getId())}/>,
                            defaultTab: true
                        },
                        {
                            label: t`Static Data`,
                            component: <TicketStaticDataModelTable/>
                        }
                    ]}
                />
            </Box>
        </ModelProvider>
    )
});