import {observer} from "mobx-react-lite";
import React, {useEffect} from "react";
import {PaddedPaper} from "@rx-suite/ui";
import {PerformanceMetricStore} from "../../stores/PerformanceMetricStore";
import {SuccessFailOutgoingBarChart} from "../../components/performance_metrics/SuccessFailOutgoingBarChart";
import {Box, Grid, LinearProgress, makeStyles} from "@material-ui/core";
import Typography from "@material-ui/core/Typography";
import {t} from "@lingui/macro";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import {
    OutgoingTransactionsPerTypeBarChart
} from "../../components/performance_metrics/OutgoingTransactionPerTypeBarChart";
import {
    TransactionDurationPerTypeLineChart
} from "../../components/performance_metrics/TransactionDurationPerTypeLineChart";
import {ExternalCallLoadGraph} from "../../components/performance_metrics/ExternalCallLoadGraph";

const useStyles = makeStyles((theme) => ({
    updatedAt: {

    },
    graphWrapper: {
        width:'425px',
        marginBottom: theme.spacing(1)
    }
}));

export const performanceMetrics = observer(() => {
    const classes = useStyles();

    useEffect(() => {
        const fetch = async () => {
            await PerformanceMetricStore.refreshData();
            PerformanceMetricStore.selectedModel?.subscribe();
        }
        fetch();

        return () => {
            PerformanceMetricStore.selectedModel?.unsubscribe();
        }
    }, []);

    if(PerformanceMetricStore.isLoading){
        return <LinearProgress/>
    }

    const last_update_time = (SystemSettingStore.selectedModel as SystemSettingModel).printDateTime(PerformanceMetricStore.selectedModel?.last_update_time)

    return <React.Fragment>
        <Box mb={1}>
            <Grid container justifyContent={'flex-end'}>
                <Typography className={classes.updatedAt}>{t`Updated at:` + ` ${last_update_time}`}</Typography>
            </Grid>
        </Box>
        <Grid container justifyContent={'space-evenly'}>
            {
                [
                    SuccessFailOutgoingBarChart,
                    OutgoingTransactionsPerTypeBarChart,
                    TransactionDurationPerTypeLineChart,
                    ExternalCallLoadGraph
                ].map(Component => {
                        return (<Grid item className={classes.graphWrapper}>
                                    <PaddedPaper>
                                        <Box p={1}>
                                            <Component/>
                                        </Box>
                                    </PaddedPaper>
                                </Grid>
                            )
                    })
            }
        </Grid>
    </React.Fragment>
})