import React from "react";
import {FormProps, ModelForm, TabsContainer} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {SettingModel, SettingStore} from "../../stores/SettingStore";
import {LinearProgress} from "@material-ui/core";
import {ConnectionsTab} from "./tabs/ConnectionsTab";
import {OrderLaunchingTab} from "./tabs/OrderLaunchingTab";
import {TicketLedTab} from "./tabs/TicketLedTab";
import {ExternalSystemTab} from "./tabs/ExternalSystemTab";

export const SettingForm: React.FunctionComponent<FormProps> = observer(() => {
    const model = SettingStore.selectedModel as SettingModel;

    if (!model) {
        return <LinearProgress color={"secondary"}/>
    }

    return (
        <ModelForm model={model} suppressImportExport suppressMakeCopy>
            <TabsContainer tabs={[
                {
                    label: t`Connections`,
                    component: <ConnectionsTab/>,
                    defaultTab: true
                },
                {
                    label: t`Order Launching`,
                    component: <OrderLaunchingTab/>,
                },
                {
                    label: t`Ticket LED`,
                    component: <TicketLedTab/>
                },
                {
                    label: t`External Systems`,
                    component: <ExternalSystemTab/>
                }
            ]}/>
        </ModelForm>
    )
});