import * as React from "react";
import {observer} from "mobx-react-lite";
import {FormProps, ModelForm, ModelInput, ModelSelect} from "@rx-suite/ui";
import {TagModel} from "../../stores/TagStore";
import {grey} from "@material-ui/core/colors";
import {Trans} from "@lingui/macro";
import Typography from "@material-ui/core/Typography";
import {createStyles, makeStyles, Theme} from "@material-ui/core";

type TagFormProps = {
    model: TagModel
} & Omit<FormProps, 'model'>;

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        bold: {
            fontWeight: 'bold'
        },
        caption: {
            color: grey[500],
            fontSize: '0.75rem'
        }
    })
);

export const TagForm: React.FunctionComponent<TagFormProps> = observer(({model}) => {
    const classes = useStyles();

    return (
        <ModelForm model={model} suppressImportExport suppressMakeCopy>
            <ModelInput name={'tag'} disabled={!model.isNew}/>
            <ModelSelect name={'value_type'} options={[
                {label: 'String', value: 'string'},
                {label: 'Number', value: 'number'},
                {label: 'Barcode', value: 'barcode'},
                {label: 'Boolean', value: 'boolean'}
            ]} disabled={!model.isNew}/>
            <ModelInput name={'default_value'} hint={{title: 'Tag Default Value', children:
                    <div>
                        <div><Trans>The default value used if a job's data does not contain this tag.</Trans></div>
                        <br/>
                        <div><Trans><span className={classes.bold}>Important:</span> A default value should be provided if a tag may not have a value, otherwise, any conditions using this tag may return unexpected results.</Trans></div>
                    </div>
            }}/>
            <Typography variant={'h6'} className={classes.caption}>
                <Trans>Important: Use a dot to represent decimal values in numbers (ex: 0.5 instead of 0,5).</Trans>
            </Typography>
        </ModelForm>
    );
})
