import * as React from "react";
import {observer} from "mobx-react-lite";
import {Conditional, FormProps, ModelForm, ModelInput, ModelSelect, PaddedPaper} from "@rx-suite/ui";
import {TicketTemplateModel} from "../../stores/TicketTemplateStore";
import {t} from "@lingui/macro";
import {TicketTemplateFields} from "./ticket_template_fields/TicketTemplateFields";
import {WorkflowStore} from "../../stores/WorkflowStore";
import Alert from "@material-ui/lab/Alert";
import {Typography} from "@material-ui/core";

type TicketTemplateFormProps = {
    model: TicketTemplateModel
} & Omit<FormProps, 'model'>

export const TicketTemplateForm: React.FunctionComponent<TicketTemplateFormProps> = observer(({model}) => {
    const workflows = WorkflowStore.getAll();

    const workflowOptions = React.useMemo(() => {
        return workflows.map((model) => {
            return { label: model.name, value: model.getId() }
        });
    }, [workflows])

    return (
        <PaddedPaper>
            <Conditional condition={model.system_default}>
                <Alert severity="info">
                    <Typography>{t`This template is a system default and may have some inputs disabled.`}</Typography>
                </Alert>
            </Conditional>
            <ModelForm model={model} suppressImportExport suppressMakeCopy suppressWrapper>
                <ModelInput name={'process_name'} disabled={model.system_default}/>
                <ModelInput name={'template_name'}
                            disabled={model.isRelease}
                            hint={
                                {
                                    title: t`Template Name`,
                                    text: t`This field must match the template name used in the external template tool.`
                                }
                            }
                />
                <ModelInput name={'process_code'}
                            disabled={model.system_default}
                            hint={
                                {
                                    title: t`Process Code`,
                                    text: t`Code used to automatically trigger template changes from external tools.`
                                }
                            }
                />
                <ModelSelect name={'workflow_id'}
                             disabled={model.system_default}
                             options={workflowOptions}
                             hint={
                                 {
                                     title: t`Workflow`,
                                     text: t`Workflow to which this ticket template belongs to`
                                 }
                             }
                />
                <TicketTemplateFields model={model}/>
            </ModelForm>
        </PaddedPaper>
    );
})
