import * as React from "react";
import {observer} from "mobx-react-lite";
import {Conditional, ModelInput, ModelSelect, useModelContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {TagStore} from "../../../stores/TagStore";
import {TicketTemplateFieldModel} from "../../../stores/TicketTemplateFieldStore";
import {HintList} from "../../../components/generic/HintList";

export const TicketTemplateFieldForm: React.FunctionComponent = observer(({}) => {
    TagStore.getAll();

    const model = useModelContext() as TicketTemplateFieldModel;

    const tagOptions = TagStore.models.map(tagModel => {
        return {label: tagModel.tag, value: tagModel.id};
    });

    const sideOptions = [
        {value: "left", label: t`Left`},
        {value: "right", label: t`Right`},
        {value: "either", label: t`Either`}
    ];

    const fieldTypeHint = [
        {title: t`Job Data`, text: t`The zone value will use the value of the tag found in the job file.`},
        {title: t`Ticket Static Data`, text: t`The zone value will use the value found in associated ticket static data.`}
    ]

    return (
        <React.Fragment>
            <ModelInput name={'zone_identifier'}/>
            <ModelSelect
                name={'field_type'}
                options={[
                    {label: "Job Data (Tags)",  value: "job_data"},
                    {label: "Ticket Static Data",  value: "ticket_data"}
                ]}
                hint={
                    {
                        title: t`Field Type`,
                        children: <HintList items={fieldTypeHint}/>
                    }
                }
            />
            <Conditional condition={model.viewModel.isJobDataField}>
                <ModelSelect
                    label={t`Tag`}
                    name={'tag_id'}
                    options={tagOptions}
                />
                <ModelSelect
                    name={'side'}
                    options={sideOptions}
                    hint={
                        {
                            title: t`Side`,
                            text: t`The side of the job data to be used for this field. If 'either' is selected, uses data from either side (left is prioritized).`
                        }
                    }
                />
            </Conditional>
            <Conditional condition={model.viewModel.isTicketDataField}>
                <ModelInput
                    label={t`Field Name`}
                    name={'static_field'}
                    hint={
                        {
                            title: t`Field Name`,
                            text: t`The field name should match the name of a field defined in the E-Ticket static data.`
                        }
                    }
                />
                <ModelInput
                    label={t`Default Value`}
                    name={'static_default'}
                />
            </Conditional>
            <ModelInput name={'formatter_regex'}/>
        </React.Fragment>
    );
})
