import * as React from 'react';
import {Grid, LinearProgress, makeStyles, Paper} from "@material-ui/core";
import {WorkflowStore} from "../../stores/WorkflowStore";
import Typography from "@material-ui/core/Typography";
import {observer} from "mobx-react-lite";
import RefreshIcon from "@material-ui/icons/Refresh";
import {ButtonField, Conditional} from "@rx-suite/ui";
import {grey} from "@material-ui/core/colors";
import Box from "@material-ui/core/Box";
import {SystemSettingModel, SystemSettingStore} from '@rx-suite/stores';
import {t} from "@lingui/macro";
import {InlineWarning} from "../../components/generic/InlineWarning";

const useStyles = makeStyles((theme) => ({
    cards: {
        width: '375px',
        height: '100%',
        backgroundColor: '#fff',
        padding: theme.spacing(5),
        textAlign: 'center'
    },
    name: {
        fontSize: '3.5rem',
        color: grey[600]
    },
    count: {
        fontSize: '2.25rem',
    },
    updateTime: {
        fontSize: '0.75rem',
        color: grey[600]
    }
}));

export const TicketInWorkflowView: React.FunctionComponent = observer(() => {
    const settings = SystemSettingStore.selectedModel as SystemSettingModel;
    const classes = useStyles();

    React.useEffect(() => {
        WorkflowStore.refreshTicketCounts();
    }, [])

    const content = React.useMemo(() => {
        const capitalize = (string: string) => {
            return string[0].toUpperCase() + string.slice(1).toLowerCase()
        }

        if(WorkflowStore.workflowTicketCounts.length === 0 && WorkflowStore.fetchingStats){
            return <LinearProgress/>;
        }

        if(WorkflowStore.workflowTicketCounts.length === 0){
            return <InlineWarning text={t`No Workflows to show. Please create one or more workflows to view this page.`}/>;
        }

        return (
            <Grid container>
                {
                    WorkflowStore.workflowTicketCounts.map(workflow => {
                        return (
                            <Box mr={5} mb={5}>
                                <Paper className={classes.cards}>
                                    <Grid container style={{height: '100%'}} direction={'column'} justifyContent={'space-between'}>
                                        <Typography className={classes.name}>{capitalize(workflow.name)}</Typography>
                                        <Typography className={classes.count}>{`${workflow.count} Tickets`}</Typography>
                                    </Grid>
                                </Paper>
                            </Box>
                        )
                    })
                }
            </Grid>
        )
    },[WorkflowStore.fetchingStats, WorkflowStore.workflowTicketCounts])

    const handleRefresh = React.useCallback(async () => {
        WorkflowStore.refreshTicketCounts();
    }, []);

    return (
        <React.Fragment>
            <Box mb={1}>
                <Grid container justifyContent={'flex-end'}>
                    <Grid container style={{width: 'fit-content'}} direction={'column'}>
                        <ButtonField
                            text={'Refresh Stats'}
                            onClick={handleRefresh}
                            startIcon={<RefreshIcon/>}
                            loading={WorkflowStore.fetchingStats}
                        />
                        <Box ml={1}>
                            <Typography className={classes.updateTime}>{`Updated at: ${settings.printTime(WorkflowStore.countsUpdatedAt)}`}</Typography>
                        </Box>
                    </Grid>
                </Grid>
            </Box>
            {content}
        </React.Fragment>
    )
});