import * as React from 'react';
import {BreadModel, makeColumn} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {TicketTemplateStore} from "../../stores/TicketTemplateStore";
import {TicketWorkstationModel, TicketWorkstationStore} from "../../stores/TicketWorkstationStore";
import {WorkstationForm} from "./WorkstationForm";

export const WorkstationBreadModel =() => {
    const columns = React.useMemo( () => {
        return [
            makeColumn('name', t`Workstation Name`, "string"),
            {
                Header: t`Display Order`,
                accessor: (workstation: TicketWorkstationModel) => workstation,
                id: 'display_order',
                filterable: false,
                Cell: (cellInfo: { value: TicketWorkstationModel }) => {
                    return cellInfo.value.display_order;
                }
            },
            {
                Header: t`Process Name`,
                accessor: (workstation: TicketWorkstationModel) => workstation,
                id: 'process_name',
                sortable: false,
                filterable: false,
                Cell: (cellInfo: { value: TicketWorkstationModel }) => {
                    const template = TicketTemplateStore.models.find(t => t.getId() == cellInfo.value.ticket_template_id);

                    if(!template){
                        return null;
                    }

                    return template.process_name;
                }
            }
        ];
    }, [TicketTemplateStore.models]);

    return (
        <BreadModel
            store={TicketWorkstationStore}
            Form={WorkstationForm}
            columns={columns}
            tableProps={
                {
                    defaultFiltered: [{id: "action", value: '[0, 5]', strictMatchFilter: true}], // Only show the write workstation as the others cannot be edited
                    defaultSorted: [{id: "display_order", desc: true}]
                }
            }
        />
    )
}