import * as React from "react";
import {observer} from "mobx-react-lite";
import {FormProps, ModelForm, ModelInput, ModelSelect} from "@rx-suite/ui";
import {TicketTemplateStore} from "../../stores/TicketTemplateStore";
import {t} from "@lingui/macro";
import {TicketWorkstationModel, TicketWorkstationStore} from "../../stores/TicketWorkstationStore";

type TemplateWorkstationFormProps = {
    model: TicketWorkstationModel
} & Omit<FormProps, 'model'>

export const WorkstationForm: React.FunctionComponent<TemplateWorkstationFormProps> = observer(({model}) => {
    const ticketTemplates = TicketTemplateStore.getAll();

    const options = React.useMemo(() => {
        return ticketTemplates
            .filter(template => !template.system_default)
            .map((model) => {
                return { label: model.process_name, value: model.getId()
            }
        });
    }, [ticketTemplates]);

    return (
        <ModelForm model={model} suppressImportExport suppressMakeCopy>
            <ModelInput name={'name'}/>
            <ModelSelect name={'action'} options={TicketWorkstationStore.workstationActionOptions}/>
            {model.isWriteTemplateWorkstation &&
                <ModelSelect name={'ticket_template_id'} options={options}/>
            }
            <ModelInput name={'display_order'}
                        type={'number'}
                        inputProps={
                            {
                                min: '1',
                                max: '999',
                                step: '1'
                            }
                        }
                        hint={
                            {
                                title: t`Workstation Sort Order`,
                                text: t`Order in which to display the workstations in the menu. Smaller values will appear first in the list.`
                            }
                        }
            />
        </ModelForm>
    );
})
