import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import {t} from "@lingui/macro";

type ValueType = 'string' | 'number' | 'barcode' | 'boolean';

@model({
    transportLayer: "/api/tags",
    permissionTarget: "TicketTemplate",
    routingInfo: {
        create: '/settings/tags/create',
        read: '/settings/tags/:id/read',
        update: '/settings/tags/:id/edit'
    },
    eager: true
})
export class TagModel extends Model {
    @attribute({
        label: t`Tag`,
        validation: yup.string().required(t`Tag is a required field`)
    })
    tag: string = ""

    @attribute({
        label: t`Value Type`,
        validation: yup.string().required(t`Value Type is a required field`)
    })
    value_type: ValueType = "string"

    @attribute({
        label: t`Default Value`,
        validation: yup.string().nullable()
    })
    default_value: string | null = null

    constructor() {
        super();
        super.setup();
    }
}

export const TagStore = TagModel.store as DataStore<TagModel>;