import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import {t} from "@lingui/macro";
import {computed, override} from "mobx";
import {string} from "yup";

@model({
    transportLayer: "/api/ticket_template_fields",
    permissionTarget: "TicketTemplate",
    routingInfo: {
        create: '/ticket_template_fields/create',
        read: '/ticket_template_fields/:id/read',
        update: '/ticket_template_fields/:id/edit'
    }
})
export class TicketTemplateFieldModel extends Model {
    @attribute({ label: t`Ticket Template ID` })
    ticket_template_id: number | null = null

    @attribute({
        label: t`Zone ID`,
        validation: yup.string().required(t`Zone ID is a required field.`)
    })
    zone_identifier: string = ""

    @attribute({
        label: t`Field Type`,
        validation: yup.string()
    })
    field_type: "job_data" | "ticket_data" = "job_data"

    @attribute({
        label: t`Tag`,
        validation: string().when('isJobDataField',{
            is: true,
            then: schema => schema.required(t`Tag is a required field.`),
            otherwise: schema => schema.nullable()
        })
    })
    tag_id: number | null = null

    @attribute({
        label: t`Side`,
        validation: string().when('isJobDataField',{
            is: true,
            then: schema => schema.required(t`Side is a required field.`),
            otherwise: schema => schema.nullable()
        })
    })
    side: FieldSide | null = null

    @attribute({
        label: t`Field Name`,
        validation: string().when('isTicketDataField',{
            is: true,
            then: schema => schema.required(t`Field Name is a required field.`),
            otherwise: schema => schema.nullable()
        })
    })
    static_field: string | null = null

    @attribute({
        label: t`Default Field Value`,
        validation: yup.string().nullable()
    })
    static_default: string | null = null

    @attribute({
        label: t`Formatter (Regex)`,
        validation: yup.string().nullable()
    })
    formatter_regex: string | null = null

    @computed
    get isJobDataField() {
        return this.field_type === "job_data";
    }

    @computed
    get isTicketDataField() {
        return this.field_type === "ticket_data";
    }

    @computed
    get resolvedFieldType() {
        if(this.field_type === 'ticket_data'){
            return 'Ticket Static Data';
        }
        if(this.field_type === 'job_data'){
            return 'Job Data';
        }
        return '';
    }

    @override
    handleSelectChange(name: string | undefined, value: (string | Array<string> | boolean | Array<boolean> | number | Array<number>)) {
        super.handleSelectChange(name, value);

        if(name === 'field_type'){
            if(value != 'job_data'){
                this.nestedAssignment('tag_id', null);
                this.nestedAssignment('side', null);
            }
            if(value != 'ticket_data'){
                this.nestedAssignment('static_field', null);
                this.nestedAssignment('static_default', null);
            }
        }
    }

    constructor() {
        super();
        super.setup();
    }
}

type FieldSide = 'right' | 'left' | 'either';

export const TicketTemplateFieldStore = TicketTemplateFieldModel.store as DataStore<TicketTemplateFieldModel>;