import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import {t} from "@lingui/macro";
import {computed} from "mobx";
import {TicketTemplateFieldModel} from "./TicketTemplateFieldStore";
import {string} from "yup";

@model({
    transportLayer: "/api/ticket_templates",
    permissionTarget: "TicketTemplate",
    routingInfo: {
        create: '/settings/ticket_templates/create',
        read: '/settings/ticket_templates/:id/read',
        update: '/settings/ticket_templates/:id/edit'
    },
    eager: true
})
export class TicketTemplateModel extends Model {
    @attribute({
        label: t`Process Name`,
        validation: yup.string().required(t`Process Name is a required field.`)
    })
    process_name: string = ""

    @attribute({
        label: t`Template Name`,
        validation: string().when('isRelease',{
            is: true,
            then: schema => schema.nullable(),
            otherwise: schema => schema.required(t`Template Name is a required field.`)
        })
    })
    template_name: string = ""

    @attribute({
        label: t`Process Code`,
        validation: yup.string().required(t`Process Code is a required field.`)
    })
    process_code: string = ""

    @attribute({
        label: t`Workflow`,
        validation: string().when('system_default',{
            is: true,
            then: schema => schema.nullable(),
            otherwise: schema => schema.required(t`Workflow is a required field.`)
        })
    })
    workflow_id: string | null = null

    @attribute()
    system_default: boolean = false;

    @attribute({})
    new_template_fields: TicketTemplateFieldModel[] = [];

    @computed
    get isRelease(){
        return this.process_code === 'release';
    }

    canDelete(): boolean {
        return this.system_default === false;
    }

    constructor() {
        super();
        super.setup();
    }
}

export const TicketTemplateStore = TicketTemplateModel.store as DataStore<TicketTemplateModel>;