import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import {t} from "@lingui/macro";
import {action, makeObservable, observable} from "mobx";
import moment, {Moment} from "moment";

type WorkFlowTicketCount = {
    count: number;
    name: string;
}

class WorkflowStoreDataStore<T extends Model> extends DataStore<T> {
    @observable fetchingStats: boolean = false;

    @observable workflowTicketCounts: WorkFlowTicketCount[] = [];

    @observable countsUpdatedAt: Moment = moment();

    @action
    async refreshTicketCounts() {
        if(this.fetchingStats){
            return;
        }

        this.fetchingStats = true;

        try {
            const response = await this.transportLayer.fetch(`/ticket_counts`);

            const data = await response.json();

            this.workflowTicketCounts = data['counts'];
        } catch(err) {
            console.error(err);
        }

        this.countUpdatedAt = moment();

        this.fetchingStats = false;
    }

    constructor(model, transportLayer, permissionTarget, routingInfo, eager) {
        super(model, transportLayer, permissionTarget, routingInfo, eager);
        makeObservable(this);
    }
}


@model({
    transportLayer: "/api/workflows",
    permissionTarget: "Workflow",
    routingInfo: {
        create: '/settings/workflows/create',
        read: '/settings/workflows/:id/read',
        update: '/settings/workflows/:id/edit'
    },
    storeClass: WorkflowStoreDataStore
})
export class WorkflowModel extends Model {
    @attribute({
        label: t`Name`,
        validation: yup.string().required(t`Name is a required field`)
    })
    name: string | null = null;

    @attribute({})
    in_use: boolean = false;

    @attribute({})
    ticket_template_ids: string[] = [];

    canDelete(): boolean {
        return !this.in_use;
    }

    constructor() {
        super();
        super.setup();
    }
}

export const WorkflowStore = WorkflowModel.store as WorkflowStoreDataStore<WorkflowModel>;