module BulkAction
  module OrderBulkAction
    class ReleaseOrderJob < OrderBulkActionJob

      class << self
        def on_queued(successful_transactions)
          tickets = OrderBulkActionJob.paperless_tickets_for_broadcast_from_transactions(successful_transactions)
          tickets.update_all(releasing: true)
          PaperlessTicket.broadcast_multiple_now(tickets)
        end
      end

      def endpoint
        PaperlessApi::Asynchronous::Endpoints::Clear
      end

      def inject_data
        inject_release_template_data

        inject_stop_blink_hot_job
      end

      def on_transaction_invalidate(invalidated_transactions)
        tickets = OrderBulkActionJob.paperless_tickets_for_broadcast_from_transactions(invalidated_transactions)
        tickets.update_all(releasing: false)
        PaperlessTicket.broadcast_multiple_later(tickets)
      end

      def inject_stop_blink_hot_job
        @valid_transactions.each do |transaction_id, order_transaction|
          @valid_transactions[transaction_id][:data][:stop_blink] = order_transaction[:transaction].paperless_ticket.order_record.is_hot_job
        end
      end

      def inject_release_template_data
        order_record_data_base = {}

        # Because tickets might not have static data, we need to at least have a base object to build the template data
        @valid_transactions.each do |_, transaction_wrapper|
          order_record_id = transaction_wrapper[:transaction].paperless_ticket.order_record.id
          order_record_data_base[order_record_id] = {}
        end

        order_static_data = PaperlessTicket.ticket_static_data_by_order_record(@valid_transactions
                                                                                 .map {|_, transaction_wrapper|
                                                                                   transaction_wrapper[:transaction].paperless_ticket.id
                                                                                 })

        order_template_data = merge_order_data_hashes(order_record_data_base, order_static_data)

        order_template_payloads = TicketTemplate.release_template.resolve_template_for_data_records(order_template_data)

        match_template_data_to_valid_transactions(order_template_payloads)
      end
    end
  end
end
