class JsonLogic
  class << self
    # Only works with 1 table and 1 column
    # makes an arel Node describing the JSONLogic logic, which can then be put into a where to query.
    def build_arel_conditions_from_logic(logic, table, column, only_subgroup='')
      if logic.is_a?(Hash)
        logic.each do |key, value|
          case key
          when 'or'
            conditions = value.map { |sub_logic| build_arel_conditions_from_logic(sub_logic, table, column, only_subgroup) }.compact
            return [] if conditions.blank?
            return conditions.reduce(:or) if conditions.any?
          when 'and'
            conditions = value.map { |sub_logic| build_arel_conditions_from_logic(sub_logic, table, column, only_subgroup) }.compact
            return [] if conditions.blank?
            return conditions.reduce(:and) if conditions.any?
          when '!'
            sub_condition = build_arel_conditions_from_logic(value, table, column, only_subgroup)
            return sub_condition.not if sub_condition
          when '=='
            var = value[0]['var']
            return unless var.include?(only_subgroup)
            return table.arel_table[column].eq(value[1])
          when '!='
            var = value[0]['var']
            return unless var.include?(only_subgroup)
            return table.arel_table[column].not_eq(value[1])
          else
            return nil
          end
        end
      end
    end

    def order_matches_query(order_id, data, json_query)
      results = data[:tags].map do |side, tags|
        data_node = json_query['data'].deep_dup
        data_node.each do |key, value|
          case(key)
          when 'template'
            data_node[key] = OrderRecord.where(id: order_id).first&.paperless_ticket&.ticket_template&.template_name
          when 'tags'
            value.each do |tag_key, val|
              data_node[key][tag_key] = tags[tag_key]
            end
          end
        end

        JSONLogic.apply(json_query['logic'], data_node)
      end
      results.any? {|r| r == true}
    end

    def operator_to_arel_op(operator, inverse=false)
      return inverse_operator_to_arel_op(operator) if inverse
      case operator
      when '=='
        'eq'
      when '!='
        'not_eq'
      else
        'eq'
      end
    end

    def inverse_operator_to_arel_op(operator)
      case operator
      when '=='
        'not_eq'
      when '!='
        'eq'
      else
        'not_eq'
      end
    end

    def get_tags(object)
      object['data']['tags']
    end
  end
end