class MetricsCalculator
  NUM_BUCKETS = 12
  INTERVAL_BUCKETS = 5.minutes

  class << self
    def get_metrics_from_cache(start_time)
      Rails.cache.fetch([self, start_time], expires_in: 1.minutes) do
        self.new(start_time).run
      end
    end

    def get_metrics_pseudo_model
      start_time = Time.zone.now

      {
        id: 1,
        success_fail_outgoing: PerformanceMetric::SuccessFailOutgoingTransactions.get_metrics_from_cache(start_time),
        outgoing_per_type: PerformanceMetric::OutgoingTransactionsPerType.get_metrics_from_cache(start_time),
        transaction_duration_per_type: PerformanceMetric::TransactionDurationPerType.get_metrics_from_cache(start_time),
        external_call_load: PerformanceMetric::ExternalCallLoad.get_metrics_from_cache(start_time)
      }
    end
  end

  def initialize(start_time=Time.zone.now)
    @start_time = start_time
  end

  def run
    raise NotImplementedError
  end

  private

  def time_slots
    return @time_slots if @time_slots

    last_bucket = round_down_to_5_minutes(@start_time)
    first_bucket = last_bucket.advance(hours: -1)
    @time_slots = []
    (first_bucket.to_i..last_bucket.to_i).step(5.minutes) do |bucket_time|
      @time_slots << Time.zone.at(bucket_time)
    end
    @time_slots
  end

  def bucket_hash
    @bucket_hash
  end

  def calc_bucket_hash(default_value = 0)
    return @bucket_hash if @bucket_hash
    @bucket_hash = {}
    time_slots.each do |time|
      if default_value.is_a? Array
        if default_value[0].is_a? Object
          default_value = default_value.map {|value| value.deep_dup}
        else
          default_value = [*default_value]
        end
      end
      @bucket_hash[time] = default_value
    end
    @bucket_hash
  end

  def bucket_hash_to_buckets
    raise NotImplementedError
  end

  def wheres
    PaperlessApiTransaction.arel_table[:created_at].gteq(time_slots[0]).and(
      PaperlessApiTransaction.arel_table[:created_at].lt(time_slots[-1].advance(minutes: 5))
    )
  end

  def round_up_to_5_minutes(t)
    Time.at((t.to_i / 300.0).ceil * 300)
  end

  def round_down_to_5_minutes(t)
    Time.at((t.to_i / 300.0).floor * 300)
  end

  def wrap_data(data)
    {
      data: data
    }
  end

  def format_time_labels(labels)
    labels.map {|label| time_label_formatting(label)}
  end

  def time_label_formatting(time)
    "#{time.strftime('%H:%M')}"
  end

  def transaction_type_to_endpoint_type(transaction_type)
    case transaction_type
    when 'set_hot', 'clear_hot', 'find', 'stop_find'
      'Blink'
    when 'release'
      'Clear'
    when 'launch', 'set_template'
      'Write'
    end
  end

  def endpoint_types
    {
      'Blink' => 0,
      'Clear' => 1,
      'Write' => 2
    }
  end

  def avg_bucket_index
    endpoint_types.length
  end
end