class OrderLaunch
  class << self
    # Expects array of hashes [{number: order_number, ticket_barcode: e-ticket barcode}]
    def with_order_number_and_ticket_barcode(order_number_ticket_barcodes, source='SYSTEM')
      failed_pre_transaction = []

      # Create order record for each requested order
      order_create_data = OrderRecord.create_order_records_for_launch_numbers(order_number_ticket_barcodes.map{|order| order[:number]})
      failed_pre_transaction.concat order_create_data[:failed]

      # For all successfully created orders, pair them with the requested ticket
      order_record_ticket_barcodes = order_create_data[:successful].map do |order_record|
        order_data = order_number_ticket_barcodes.detect {|data| data[:number] == order_record.number}
        {order_record: order_record, ticket_barcode: order_data[:ticket_barcode]}
      end

      order_transaction_data = OrderLaunch.with_order_record_and_ticket_barcode(order_record_ticket_barcodes, source)

      order_transaction_data[:failed].concat failed_pre_transaction

      order_transaction_data
    end

    # Expects array of hashes [{order_record: OrderRecord, ticket_barcode: e-ticket barcode}]
    def with_order_record_and_ticket_barcode(order_record_ticket_barcodes, source='SYSTEM')
      ticket_associate_data = PaperlessTicket.associate_order_records_to_specific(order_record_ticket_barcodes)
      failed_in_association = ticket_associate_data[:failed].map {|failed| {order_number: failed[:order_record].number, error: failed[:error], code: failed[:code]}}

      mark_failed_associations(ticket_associate_data[:failed])

      order_transaction_data = launch_associated_orders(ticket_associate_data[:successful], source)

      order_transaction_data[:failed].concat failed_in_association

      order_transaction_data
    end

    def with_order_record_and_next_available(order_records, source='SYSTEM')
      return_obj = { associated: [], not_associated: [], failed: [] }

      ticket_associate_data = PaperlessTicket.associate_order_records_to_available(order_records)

      return_obj[:not_associated] = ticket_associate_data[:not_associated]

      return_obj[:failed].concat ticket_associate_data[:failed].map {|failed| {order_number: failed[:order_record].number, error: failed[:error], code: failed[:code]}}

      mark_failed_associations(ticket_associate_data[:failed])

      order_transaction_data = launch_associated_orders(ticket_associate_data[:associated], source)

      return_obj[:associated].concat order_transaction_data[:successful]
      return_obj[:failed].concat order_transaction_data[:failed]

      return_obj
    end

    private

    def launch_associated_orders(successfully_associated, source)
      order_numbers = successfully_associated.map { |order_record| order_record.number }

      transaction_wrappers = BulkAction::OrderBulkAction::LaunchOrderJob.perform_later(order_numbers, :launch, source: source)

      transaction_wrappers
    end

    def mark_failed_associations(failed_ticket_associations)
      update_data = failed_ticket_associations.map do |failed|
        {
          id: failed[:order_record].id,
          state: 1, # failed_launch
          failed_reason: "(#{failed[:code]}) #{failed[:error]}"
        }
      end

      OrderRecord.bulk_update(update_data)
    end
  end
end
