class OrderLaunchQueue
  include Singleton

  def launch_now(order_record)
    # The order record could have been launched automatically, so revalidate its state
    unless order_record.can_be_launched?
      return {success: false, error: 'Order is not waiting to be launched', code: :ORDER_NOT_IN_WAITING_FOR_LAUNCH}
    end

    result = OrderLaunch.with_order_record_and_next_available([order_record])

    unless result[:failed].empty?
      failed_obj = result[:failed].first
      return {success: false, error: failed_obj[:error], code: failed_obj[:code]}
    end

    return {success: false, error: 'No Tickets Available to be Associated', code: :NO_TICKET_AVAILABLE} unless result[:not_associated].empty?

    {success: true}
  end

  def launch_all_waiting
    OrderRecord.limit(launch_batch_size).waiting_for_launch.order(created_at: :asc).find_in_batches(batch_size: 20) do |orders|
      OrderLaunch.with_order_record_and_next_available(orders)
    end
  end

  private

  def launch_batch_size
    Setting.instance.max_launch_records
  end
end