module PdfFileManager
  require 'fileutils'

  class NoJobFolderPath < StandardError; end

  def files_from_dir
    return [] unless Dir.exist?(base_dir)
    Dir.entries(base_dir)
       .select { |f| File.file?(base_file_path(f)) }
       .sort_by { |f| File.stat(base_file_path(f)).ctime }
       .map { |filename| {
         filename: filename,
         launchNumber: apply_job_number_regex(filename)
       }}
  end

  def invalidate_file(filename, target_filename = nil)
    Dir.mkdir(failed_queue_dir) unless Dir.exist?(failed_queue_dir)
    FileUtils.mv(base_file_path(filename), failed_queue_file_path(target_filename ? target_filename : filename))
  end

  def delete_file(filename)
    File.delete(base_file_path(filename)) if File.exist?(base_file_path(filename))
  end

  def file_path_for_job_number(job_number)
    base_file_path("#{job_number}.pdf")
  end

  def file_path_for_file_name(file_name)
    base_file_path(file_name)
  end

  private

  def apply_job_number_regex(filename)
    setting = Setting.instance
    m = filename.match /(#{setting.regex}).(?i)pdf/
    return nil if m.nil?
    m[1]
  end

  def failed_queue_file_path(filename)
    "#{failed_queue_dir}/#{filename}"
  end

  def base_file_path(filename)
    "#{base_dir}/#{filename}"
  end

  def failed_queue_dir
    "#{base_dir}/failed_queue"
  end

  def base_dir
    raise NoJobFolderPath if Setting.instance.job_folder_path.nil?
    "#{Setting.instance.job_folder_path}"
  end
end