module PerformanceMetric
  class ExternalCallLoad < MetricsCalculator
    def run
      calc_bucket_hash(0)
      transactions = PaperlessApiTransaction.where(wheres)
      transactions.find_each do |transaction|
        bucket_time = round_down_to_5_minutes(transaction.created_at)
        bucket_hash[bucket_time] += 1
      end
      {
        series: bucket_hash_to_buckets,
        categories: format_time_labels(time_slots)
      }
    end

    private

    def wheres
      super.and(PaperlessApiTransaction.arel_table[:source].not_eq(system_col))
    end

    def system_col
      'SYSTEM'
    end

    def bucket_hash_to_buckets
      arr = []
      @bucket_hash.keys.sort_by {|e| e.to_i}.each do |key|
        arr << @bucket_hash[key]
      end
      [
        {
          name: 'External Calls',
          data: arr
        }
      ]
    end
  end
end