module PerformanceMetric
  class SuccessFailOutgoingTransactions < MetricsCalculator
    def run
      calc_bucket_hash([0,0])
      transactions = PaperlessApiTransaction.where(wheres)
      transactions.find_each do |transaction|
        bucket_time = round_down_to_5_minutes(transaction.created_at)
        bucket_hash[bucket_time][state_to_bucket_index[transaction.state]] += 1
      end
      {
        series: bucket_hash_to_buckets,
        categories: format_time_labels(time_slots)
      }
    end

    private

    def wheres
      super.and(PaperlessApiTransaction.arel_table[:state].in([2,3]))
    end

    def state_to_bucket_index
      {
        'completed' => 0,
        'failed' => 1
      }
    end

    def bucket_hash_to_buckets
      completed_arr = []
      failed_arr = []
      @bucket_hash.keys.sort_by {|e| e.to_i}.each do |key|
        completed_arr << @bucket_hash[key][0]
        failed_arr << @bucket_hash[key][1]
      end
      [
        {
          name: 'Completed',
          data: completed_arr
        },
        {
          name: 'Failed',
          data: failed_arr
        }
      ]
    end
  end
end
