module PerformanceMetric
  class TransactionDurationPerType < MetricsCalculator
    def run
      calc_bucket_hash(Array.new(endpoint_types.length + 1, {count: 0, duration: 0}))

      transactions = PaperlessApiTransaction.where(wheres)
      transactions.find_each do |transaction|
        bucket_time = round_down_to_5_minutes(transaction.created_at)
        bucket_hash[bucket_time][endpoint_types[transaction_type_to_endpoint_type(transaction.transaction_type)]][:count] += 1
        bucket_hash[bucket_time][endpoint_types[transaction_type_to_endpoint_type(transaction.transaction_type)]][:duration] += transaction.duration
      end
      calc_avg_buckets
      {
        series: bucket_hash_to_buckets,
        categories: format_time_labels(time_slots)
      }
    end

    private

    def calc_avg_buckets
      bucket_hash.each do |time, buckets|
        bucket_count = 0
        bucket_duration = 0
        buckets.each_with_index do |bucket, index|
          bucket_count += bucket[:count]
          bucket_duration += bucket[:duration]
          if bucket[:count] == 0
            bucket_hash[time][index] = 0
          else
            bucket_hash[time][index] = bucket[:duration] / bucket[:count]
          end
        end
        # Avg bucket calc
        if bucket_count == 0
          bucket_hash[time][avg_bucket_index] = 0
        else
          bucket_hash[time][avg_bucket_index] = bucket_duration / bucket_count
        end
      end
    end

    def wheres
      super.and(PaperlessApiTransaction.arel_table[:state].in([2,3,4]))
    end

    def bucket_hash_to_buckets
      arr_of_buckets = Array.new(endpoint_types.length + 1, nil)

      @bucket_hash.keys.sort_by {|e| e.to_i}.each do |key|
        @bucket_hash[key].each_with_index do |value, index|
          arr_of_buckets[index] = [] if arr_of_buckets[index].nil?
          arr_of_buckets[index] << value
        end
      end

      arr_of_buckets.map.with_index do |buckets, index|
        {
          name: index == avg_bucket_index ? 'Avg' : endpoint_types.keys[index],
          data: buckets
        }
      end
    end
  end
end
