class Setting < ApplicationRecord
  enum order_pairing_mode: [:automatic, :manual]
  # need prefix because both enums have the same values declared
  enum find_order_blink_speed: [:FLASH_1_SECOND, :FLASH_2_SECONDS, :FLASH_4_SECONDS, :FLASH_MULTI], _prefix: true
  enum hot_order_blink_speed: [:FLASH_1_SECOND, :FLASH_2_SECONDS, :FLASH_4_SECONDS, :FLASH_MULTI], _prefix: true

  after_save -> { update(auto_launch: false) if manual_pairing_on? && auto_launch_on? }

  class << self
    def instance
      Setting.first_or_create!(job_search_color: 'white',
                               job_search_duration: 1,
                               find_order_blink_speed: :FLASH_1_SECOND,
                               hot_job_color:'red',
                               hot_order_blink_speed: :FLASH_1_SECOND,
                               auto_launch: false,
                               max_launch_records: 5,
                               order_pairing_mode: :automatic)
    end

    def manual_pairing_mode
      'manual'
    end
  end

  def manual_pairing_on?
    order_pairing_mode == Setting.manual_pairing_mode
  end

  def auto_launch_on?
    auto_launch
  end

  def regex
    return '.*' if job_regex.nil?
    job_regex
  end

  def hot_job_blink_settings
    {
      color: hot_job_color,
      pattern: hot_order_blink_speed,
      duration: nil
    }
  end

  def default_find_job_blink_settings
    {
      color: job_search_color,
      pattern: find_order_blink_speed,
      duration: job_search_duration
    }
  end
end

