class CreateOrderRecords < RxModule::Routine

  class << self
    include PdfFileManager

    def frequency
      '1m'
    end

    def work
      return if missing_config? || Setting.instance.manual_pairing_on?

      launch_number_to_launch_object = {}

      files_from_dir.each do |file|
        # check pdf launchNumber
        launch_number = file[:launchNumber]
        if launch_number.nil?
          invalidate_file(file[:filename])
          next
        end

        launch_number_to_launch_object[launch_number] = {file_name: file[:filename], order: nil}
      end

      return if launch_number_to_launch_object.empty?

      results = OrderRecord.create_order_records_for_launch_numbers(launch_number_to_launch_object.keys)

      results[:successful].each do |order_record|
        launch_number_to_launch_object[order_record.launch_number][:order] = order_record
      end

      launch_number_to_launch_object = launch_number_to_launch_object.except(*results[:failed].map {|failed_obj| failed_obj[:order_number]})

      process_failed_objects(results[:failed])

      OrderRecord.attach_pdfs_to_orders(launch_number_to_launch_object.values)
    rescue => err
      Rails::logger.error "Error preparing job files - #{err}"
    end

    def missing_config?
      Setting.instance.job_folder_path.nil? || external_dcs_id.nil?
    end

    def external_dcs_id
      Setting.instance.external_dcs_id
    end

    def is_duplicate_order_number?(order_number)
      previous = OrderRecord.where(number: order_number).first

      if previous && previous.state == 'failed'
        previous.destroy!
        previous = nil
      end

      !!previous
    end

    def process_failed_objects(failed_objects)
      failed_objects.each do |failed_object|
        launch_number = failed_object[:order_number]
        case failed_object[:code]
        when :ORDER_ALREADY_LAUNCHED
          invalidate_duplicate(launch_number)
        else
          Rails::logger.warn "[Order Loader] Unknown order launch error for launch number #{launch_number}"
        end
      end
    end

    def invalidate_duplicate(launch_number)
      path = file_path_for_job_number(launch_number)
      filename = File.basename(path)
      duplicate_file_name = "duplicate-#{filename}"
      Rails::logger.warn "[Order Loader] Order number #{launch_number} already in use. Rejecting PDF as #{duplicate_file_name}"
      invalidate_file(filename, duplicate_file_name)
    end
  end
end