Rails.application.routes.draw do
  mount RxModule::Engine => "/api/rx_module"
  scope :api do
    resources :paperless_tickets, only: [:index, :show, :destroy] do
      member do
        get :current_image
        put :toggle_staged
        put :release
        put :force_stop_blink
      end
      collection do
        get :count
        put :find_by_barcode
        post :bulk_add
      end
    end
    resources :external_systems
    resources :settings, only: [:index, :update]
    resources :order_records, only: [:index, :destroy, :show] do
      member do
        get :download
        get :tags
        get :latest_launch_transaction_id
        put :change_template
        post :hot_job
        post :find_my_job
        post :launch_job
      end
      collection do
        post :fetch_by_job_number
      end
    end
    resources :paperless_api_transactions, only: [:index, :destroy, :show] do
      member do
        get :status, to: "paperless_api_transactions#refresh_status"
        put :cancel_transaction
      end
    end
    resources :tags
    resources :ticket_templates
    resources :ticket_template_fields
    resources :ticket_workstations do
      member do
        put :call
      end
    end
    resources :workflows do
      collection do
        get :ticket_counts
      end
    end
    resources :order_find_queries do
      member do
        put :execute
        put :stop
      end
    end
    resources :performance_metrics, only: [:index]
    resources :ticket_static_data

    scope "/external/v1/" do
      scope :orders do
        post "bulk-launch", to: 'external_api#bulk_launch'
        put "bulk-update", to: 'external_api#bulk_update'
        put "bulk-set-hot", to: 'external_api#bulk_set_hot'
        put "bulk-release", to: 'external_api#bulk_release'

        ### These routes are deprecated, only used in pilot beta at Jimmy Fairly
        put ":order_number/template", to: 'external_api#old_set_template'
        put "hot_job", to: 'external_api#bulk_set_hot'
      end

      get "templates", to: 'external_api#templates'
    end
  end

  post "transactions/update-status", to: "paperless_api_transactions#update_status"

  root "/", controller: :index, action: :show, as: :index_show
  match "*path" => "index#show", :via => :all
end
